@@ -1246,7 +1246,7 @@ int dw_marginal_data_density_command_line(int nargs, char **args, TStateModel *m
   // Plot marginal radius cummulative distribution
   if (dw_FindArgument_String(nargs,args,"graph") != -1)
     {
-      printf("Computing cummulative densities\n");
+      printf("Computing cumulative densities\n");
       GraphCummulativeDensities(f_out,(char*)NULL,R,elliptical);
       fclose(f_out);
       rtrn=1;
