@@ -9,8 +9,20 @@
 #include "product.h"
 #include "quasi_mcarlo.h"
 
+#ifdef __MINGW32__
+#define __CROSS_COMPILATION__
+#endif
+
+#ifdef __MINGW64__
+#define __CROSS_COMPILATION__
+#endif
+
+#ifdef __CROSS_COMPILATION__
+#define M_PI 3.14159265358979323846
+#endif
+
 /*2:*/
-#line 29 "./global_check.cweb"
+#line 41 "./global_check.cweb"
 
 ResidFunction::ResidFunction(const Approximation&app)
 :VectorFunction(app.getModel().nexog(),app.getModel().numeq()),approx(app),
@@ -20,10 +32,10 @@ yplus(NULL),ystar(NULL),u(NULL),hss(NULL)
 }
 
 /*:2*/
-#line 15 "./global_check.cweb"
+#line 27 "./global_check.cweb"
 ;
 /*3:*/
-#line 38 "./global_check.cweb"
+#line 50 "./global_check.cweb"
 
 ResidFunction::ResidFunction(const ResidFunction&rf)
 :VectorFunction(rf),approx(rf.approx),model(rf.model->clone()),
@@ -41,16 +53,16 @@ hss= new FTensorPolynomial(*(rf.hss));
 
 
 /*:3*/
-#line 16 "./global_check.cweb"
+#line 28 "./global_check.cweb"
 ;
 /*4:*/
-#line 55 "./global_check.cweb"
+#line 67 "./global_check.cweb"
 
 ResidFunction::~ResidFunction()
 {
 delete model;
 /*5:*/
-#line 63 "./global_check.cweb"
+#line 75 "./global_check.cweb"
 
 if(yplus)
 delete yplus;
@@ -63,20 +75,20 @@ delete hss;
 
 
 /*:5*/
-#line 59 "./global_check.cweb"
+#line 71 "./global_check.cweb"
 ;
 }
 
 /*:4*/
-#line 17 "./global_check.cweb"
+#line 29 "./global_check.cweb"
 ;
 /*6:*/
-#line 77 "./global_check.cweb"
+#line 89 "./global_check.cweb"
 
 void ResidFunction::setYU(const Vector&ys,const Vector&xx)
 {
 /*5:*/
-#line 63 "./global_check.cweb"
+#line 75 "./global_check.cweb"
 
 if(yplus)
 delete yplus;
@@ -89,7 +101,7 @@ delete hss;
 
 
 /*:5*/
-#line 80 "./global_check.cweb"
+#line 92 "./global_check.cweb"
 ;
 
 ystar= new Vector(ys);
@@ -99,7 +111,7 @@ approx.getFoldDecisionRule().evaluate(DecisionRule::horner,
 *yplus,*ystar,*u);
 
 /*7:*/
-#line 101 "./global_check.cweb"
+#line 113 "./global_check.cweb"
 
 union{const FoldDecisionRule*c;FoldDecisionRule*n;}dr;
 dr.c= &(approx.getFoldDecisionRule());
@@ -107,10 +119,10 @@ FTensorPolynomial dr_ss(model->nstat()+model->npred(),model->nboth()+model->nfor
 *(dr.n));
 
 /*:7*/
-#line 88 "./global_check.cweb"
+#line 100 "./global_check.cweb"
 ;
 /*8:*/
-#line 108 "./global_check.cweb"
+#line 120 "./global_check.cweb"
 
 Vector ytmp_star(ConstVector(*yplus,model->nstat(),model->npred()+model->nboth()));
 ConstVector ysteady_star(dr.c->getSteady(),model->nstat(),
@@ -118,10 +130,10 @@ model->npred()+model->nboth());
 ytmp_star.add(-1.0,ysteady_star);
 
 /*:8*/
-#line 89 "./global_check.cweb"
+#line 101 "./global_check.cweb"
 ;
 /*9:*/
-#line 115 "./global_check.cweb"
+#line 127 "./global_check.cweb"
 
 hss= new FTensorPolynomial(dr_ss,ytmp_star);
 ConstVector ysteady_ss(dr.c->getSteady(),model->nstat()+model->npred(),
@@ -135,15 +147,15 @@ hss->insert(ten);
 }
 
 /*:9*/
-#line 90 "./global_check.cweb"
+#line 102 "./global_check.cweb"
 ;
 }
 
 /*:6*/
-#line 18 "./global_check.cweb"
+#line 30 "./global_check.cweb"
 ;
 /*10:*/
-#line 130 "./global_check.cweb"
+#line 142 "./global_check.cweb"
 
 void ResidFunction::eval(const Vector&point,const ParameterSignal&sig,Vector&out)
 {
@@ -157,10 +169,10 @@ model->evaluateSystem(out,*ystar,*yplus,yss,*u);
 }
 
 /*:10*/
-#line 19 "./global_check.cweb"
+#line 31 "./global_check.cweb"
 ;
 /*11:*/
-#line 146 "./global_check.cweb"
+#line 158 "./global_check.cweb"
 
 void GlobalChecker::check(const Quadrature&quad,int level,
 const ConstVector&ys,const ConstVector&x,Vector&out)
@@ -171,10 +183,10 @@ quad.integrate(vfs,level,out);
 }
 
 /*:11*/
-#line 20 "./global_check.cweb"
+#line 32 "./global_check.cweb"
 ;
 /*12:*/
-#line 163 "./global_check.cweb"
+#line 175 "./global_check.cweb"
 
 void GlobalChecker::check(int max_evals,const ConstTwoDMatrix&y,
 const ConstTwoDMatrix&x,TwoDMatrix&out)
@@ -184,7 +196,7 @@ pa<<"Checking approximation error for "<<y.ncols()
 <<" states with at most "<<max_evals<<" evaluations"<<endrec;
 
 /*13:*/
-#line 180 "./global_check.cweb"
+#line 192 "./global_check.cweb"
 
 GaussHermite gh;
 
@@ -201,12 +213,12 @@ dummy_pq.designLevelForEvals(max_evals,prod_level,prod_evals);
 bool take_smolyak= (smol_evals<prod_evals)&&(smol_level>=prod_level-1);
 
 /*:13*/
-#line 171 "./global_check.cweb"
+#line 183 "./global_check.cweb"
 ;
 Quadrature*quad;
 int lev;
 /*14:*/
-#line 196 "./global_check.cweb"
+#line 208 "./global_check.cweb"
 
 if(take_smolyak){
 quad= new SmolyakQuadrature(model.nexog(),smol_level,gh);
@@ -225,10 +237,10 @@ rec<<"Selected product (level,evals)=("<<prod_level<<","
 }
 
 /*:14*/
-#line 174 "./global_check.cweb"
+#line 186 "./global_check.cweb"
 ;
 /*15:*/
-#line 214 "./global_check.cweb"
+#line 226 "./global_check.cweb"
 
 int first_row= (y.nrows()==model.numeq())?model.nstat():0;
 ConstTwoDMatrix ysmat(y,first_row,0,model.npred()+model.nboth(),y.ncols());
@@ -242,16 +254,16 @@ check(*quad,lev,yj,xj,outj);
 
 
 /*:15*/
-#line 175 "./global_check.cweb"
+#line 187 "./global_check.cweb"
 ;
 delete quad;
 }
 
 /*:12*/
-#line 21 "./global_check.cweb"
+#line 33 "./global_check.cweb"
 ;
 /*16:*/
-#line 231 "./global_check.cweb"
+#line 243 "./global_check.cweb"
 
 void GlobalChecker::checkAlongShocksAndSave(mat_t*fd,const char*prefix,
 int m,double mult,int max_evals)
@@ -260,7 +272,7 @@ JournalRecordPair pa(journal);
 pa<<"Calculating errors along shocks +/- "
 <<mult<<" std errors, granularity "<<m<<endrec;
 /*17:*/
-#line 248 "./global_check.cweb"
+#line 260 "./global_check.cweb"
 
 TwoDMatrix y_mat(model.numeq(),2*m*model.nexog()+1);
 for(int j= 0;j<2*m*model.nexog()+1;j++){
@@ -269,10 +281,10 @@ yj= (const Vector&)model.getSteady();
 }
 
 /*:17*/
-#line 238 "./global_check.cweb"
+#line 250 "./global_check.cweb"
 ;
 /*18:*/
-#line 256 "./global_check.cweb"
+#line 268 "./global_check.cweb"
 
 TwoDMatrix exo_mat(model.nexog(),2*m*model.nexog()+1);
 exo_mat.zeros();
@@ -286,14 +298,14 @@ mult*jmult*max_sigma/m;
 }
 
 /*:18*/
-#line 239 "./global_check.cweb"
+#line 251 "./global_check.cweb"
 ;
 
 TwoDMatrix errors(model.numeq(),2*m*model.nexog()+1);
 check(max_evals,y_mat,exo_mat,errors);
 
 /*19:*/
-#line 269 "./global_check.cweb"
+#line 281 "./global_check.cweb"
 
 TwoDMatrix res(model.nexog(),2*m+1);
 JournalRecord rec(journal);
@@ -330,15 +342,15 @@ err_out.writeMat(fd,tmp);
 
 
 /*:19*/
-#line 244 "./global_check.cweb"
+#line 256 "./global_check.cweb"
 ;
 }
 
 /*:16*/
-#line 22 "./global_check.cweb"
+#line 34 "./global_check.cweb"
 ;
 /*20:*/
-#line 318 "./global_check.cweb"
+#line 330 "./global_check.cweb"
 
 void GlobalChecker::checkOnEllipseAndSave(mat_t*fd,const char*prefix,
 int m,double mult,int max_evals)
@@ -347,7 +359,7 @@ JournalRecordPair pa(journal);
 pa<<"Calculating errors at "<<m
 <<" ellipse points scaled by "<<mult<<endrec;
 /*21:*/
-#line 336 "./global_check.cweb"
+#line 348 "./global_check.cweb"
 
 TwoDMatrix*ycov= approx.calcYCov();
 TwoDMatrix ycovpred((const TwoDMatrix&)*ycov,model.nstat(),model.nstat(),
@@ -363,10 +375,10 @@ ssd.getFactor(ycovfac);
 
 
 /*:21*/
-#line 325 "./global_check.cweb"
+#line 337 "./global_check.cweb"
 ;
 /*22:*/
-#line 361 "./global_check.cweb"
+#line 373 "./global_check.cweb"
 
 int d= model.npred()+model.nboth()-1;
 TwoDMatrix ymat(model.npred()+model.nboth(),(d==0)?2:m);
@@ -393,10 +405,10 @@ ycol[i+1]= sin(x[i]);
 }
 
 /*:22*/
-#line 326 "./global_check.cweb"
+#line 338 "./global_check.cweb"
 ;
 /*23:*/
-#line 390 "./global_check.cweb"
+#line 402 "./global_check.cweb"
 
 TwoDMatrix umat(model.nexog(),ymat.ncols());
 umat.zeros();
@@ -410,10 +422,10 @@ ycol.add(1.0,ys);
 }
 
 /*:23*/
-#line 327 "./global_check.cweb"
+#line 339 "./global_check.cweb"
 ;
 /*24:*/
-#line 403 "./global_check.cweb"
+#line 415 "./global_check.cweb"
 
 TwoDMatrix out(model.numeq(),ymat.ncols());
 check(max_evals,ymat,umat,out);
@@ -425,16 +437,16 @@ sprintf(tmp,"%s_ellipse_errors",prefix);
 out.writeMat(fd,tmp);
 
 /*:24*/
-#line 328 "./global_check.cweb"
+#line 340 "./global_check.cweb"
 ;
 }
 
 
 /*:20*/
-#line 23 "./global_check.cweb"
+#line 35 "./global_check.cweb"
 ;
 /*25:*/
-#line 416 "./global_check.cweb"
+#line 428 "./global_check.cweb"
 
 void GlobalChecker::checkAlongSimulationAndSave(mat_t*fd,const char*prefix,
 int m,int max_evals)
@@ -461,7 +473,7 @@ delete y;
 
 
 /*:25*/
-#line 24 "./global_check.cweb"
+#line 36 "./global_check.cweb"
 ;
 
 /*:1*/
