@@ -1,21 +1,22 @@
-function oo_ = GetPosteriorParametersStatistics(estim_params_, M_, options_, bayestopt_, oo_)
+function oo_ = GetPosteriorParametersStatistics(estim_params_, M_, options_, bayestopt_, oo_, pnames)
 % This function prints and saves posterior estimates after the mcmc
-% (+updates of oo_ & TeX output). 
-% 
-% INPUTS 
-%   estim_params_    [structure] 
+% (+updates of oo_ & TeX output).
+%
+% INPUTS
+%   estim_params_    [structure]
 %   M_               [structure]
 %   options_         [structure]
 %   bayestopt_       [structure]
 %   oo_              [structure]
-%  
-% OUTPUTS 
-%   oo_              [structure]  
+%   pnames           [char]        Array of char, names of the prior shapes available
+%
+% OUTPUTS
+%   oo_              [structure]
 %
 % SPECIAL REQUIREMENTS
 %   None.
 
-% Copyright (C) 2006-2013 Dynare Team
+% Copyright (C) 2006-2017 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -33,7 +34,7 @@ function oo_ = GetPosteriorParametersStatistics(estim_params_, M_, options_, bay
 % along with Dynare.  If not, see <http://www.gnu.org/licenses/>.
 
 %if ~options_.mh_replic && options_.load_mh_file
-%   load([M_.fname '_results.mat'],'oo_'); 
+%   load([M_.fname '_results.mat'],'oo_');
 %end
 
 TeX     = options_.TeX;
@@ -47,7 +48,7 @@ nx      = nvx+nvn+ncx+ncn+np;
 
 MetropolisFolder = CheckPath('metropolis',M_.dname);
 OutputFolder = CheckPath('Output',M_.dname);
-FileName = M_.fname;  
+FileName = M_.fname;
 
 load_last_mh_history_file(MetropolisFolder,FileName);
 
@@ -59,7 +60,6 @@ FirstMhFile = record.KeepedDraws.FirstMhFile;
 NumberOfDraws = TotalNumberOfMhDraws-floor(options_.mh_drop*TotalNumberOfMhDraws);
 clear record;
 
-pnames=['     ';'beta ';'gamma';'norm ';'invg ';'unif ';'invg2'];
 header_width = row_header_width(M_,estim_params_,bayestopt_);
 hpd_interval=[num2str(options_.mh_conf_sig*100), '% HPD interval'];
 tit2 = sprintf('%-*s %12s %12s %23s %8s %12s\n',header_width,' ','prior mean','post. mean',hpd_interval,'prior','pstdev');
@@ -72,10 +72,10 @@ skipline()
 try
     disp(sprintf('Log data density is %f.',oo_.MarginalDensity.ModifiedHarmonicMean))
 catch
-    [marginal,oo_] = marginal_density(M_, options_, estim_params_, oo_);
+    [marginal,oo_] = marginal_density(M_, options_, estim_params_, oo_, bayestopt_);
     disp(sprintf('Log data density is %f.',oo_.MarginalDensity.ModifiedHarmonicMean))
 end
-num_draws=length(NumberOfDraws*options_.mh_nblck);
+num_draws=NumberOfDraws*options_.mh_nblck;
 hpd_draws = round((1-options_.mh_conf_sig)*num_draws);
 if hpd_draws<2
     fprintf('posterior_moments: There are not enough draws computes to compute HPD Intervals. Skipping their computation.\n')
@@ -108,14 +108,14 @@ if np
                 [post_mean, post_median, post_var, hpd_interval, post_deciles, ...
                  density] = posterior_moments(Draws,1,options_.mh_conf_sig);
                 name = bayestopt_.name{ip};
-                oo_ = Filloo(oo_,name,type,post_mean,hpd_interval,post_median,post_var,post_deciles,density);                
+                oo_ = Filloo(oo_,name,type,post_mean,hpd_interval,post_median,post_var,post_deciles,density);
             end
         end
         disp(sprintf(pformat,header_width,name,bayestopt_.p1(ip),...
                      post_mean, ...
                      hpd_interval, ...
                      pnames(bayestopt_.pshape(ip)+1,:), ...
-                     bayestopt_.p2(ip)));    
+                     bayestopt_.p2(ip)));
         if TeX
             k = estim_params_.param_vals(i,1);
             name = deblank(M_.param_names_tex(k,:));
@@ -163,7 +163,7 @@ if nvx
         end
         disp(sprintf(pformat,header_width,name,bayestopt_.p1(ip),post_mean,hpd_interval,...
                      pnames(bayestopt_.pshape(ip)+1,:),bayestopt_.p2(ip)));
-        if TeX,
+        if TeX
             name = deblank(M_.exo_names_tex(k,:));
             TeXCore(fid,name,deblank(pnames(bayestopt_.pshape(ip)+1,:)),bayestopt_.p1(ip),...
                     bayestopt_.p2(ip),post_mean,sqrt(post_var),hpd_interval);
@@ -171,7 +171,7 @@ if nvx
         ip = ip+1;
     end
     if TeX
-        TeXEnd(fid,2,'standard deviation of structural shocks');        
+        TeXEnd(fid,2,'standard deviation of structural shocks');
     end
 end
 if nvn
@@ -188,17 +188,17 @@ if nvn
             Draws = GetAllPosteriorDraws(ip,FirstMhFile,FirstLine,TotalNumberOfMhFiles,NumberOfDraws);
             [post_mean, post_median, post_var, hpd_interval, post_deciles, density] = ...
                 posterior_moments(Draws,1,options_.mh_conf_sig);
-            name = deblank(options_.varobs(estim_params_.nvn_observable_correspondence(i,1),:));
+            name = options_.varobs{estim_params_.nvn_observable_correspondence(i,1)};
             oo_ = Filloo(oo_,name,type,post_mean,hpd_interval,post_median,post_var,post_deciles,density);
         else
             try
-                name = deblank(options_.varobs(estim_params_.nvn_observable_correspondence(i,1),:));
+                name = options_.varobs{estim_params_.nvn_observable_correspondence(i,1)};
                 [post_mean,hpd_interval,post_var] = Extractoo(oo_,name,type);
             catch
                 Draws = GetAllPosteriorDraws(ip,FirstMhFile,FirstLine,TotalNumberOfMhFiles,NumberOfDraws);
                 [post_mean, post_median, post_var, hpd_interval, post_deciles, density] = ...
                     posterior_moments(Draws,1,options_.mh_conf_sig);
-                name = deblank(options_.varobs(estim_params_.nvn_observable_correspondence(i,1),:));
+                name = options_.varobs{estim_params_.nvn_observable_correspondence(i,1)};
                 oo_ = Filloo(oo_,name,type,post_mean,hpd_interval,post_median,post_var,post_deciles,density);
             end
         end
@@ -213,7 +213,7 @@ if nvn
         ip = ip+1;
     end
     if TeX
-        TeXEnd(fid,3,'standard deviation of measurement errors');        
+        TeXEnd(fid,3,'standard deviation of measurement errors');
     end
 end
 if ncx
@@ -311,15 +311,15 @@ if ncn
         end
         disp(sprintf(pformat, header_width,name,bayestopt_.p1(ip),post_mean,hpd_interval, ...
                      pnames(bayestopt_.pshape(ip)+1,:),bayestopt_.p2(ip)));
-        if TeX,
+        if TeX
             name = ['(',deblank(M_.endo_names_tex(k1,:)) ',' deblank(M_.endo_names_tex(k2,:)),')'];
             TeXCore(fid,name,deblank(pnames(bayestopt_.pshape(ip)+1,:)),bayestopt_.p1(ip),...
-                    bayestopt_.p2(ip),post_mean,sqrt(post_var),hpd_interval);            
+                    bayestopt_.p2(ip),post_mean,sqrt(post_var),hpd_interval);
         end
         ip = ip+1;
     end
     if TeX
-        TeXEnd(fid,5,'correlation of measurement errors');        
+        TeXEnd(fid,5,'correlation of measurement errors');
     end
 end
 
@@ -328,7 +328,7 @@ end
 %% subfunctions:
 %
 function fid = TeXBegin(directory,fname,fnum,title)
-TeXfile = [directory '/' fname '_Posterior_Mean_' int2str(fnum) '.TeX'];
+TeXfile = [directory '/' fname '_Posterior_Mean_' int2str(fnum) '.tex'];
 fidTeX = fopen(TeXfile,'w');
 fprintf(fidTeX,'%% TeX-table generated by Dynare.\n');
 fprintf(fidTeX,['%% RESULTS FROM METROPOLIS HASTINGS (' title ')\n']);
@@ -336,29 +336,30 @@ fprintf(fidTeX,['%% ' datestr(now,0)]);
 fprintf(fidTeX,' \n');
 fprintf(fidTeX,' \n');
 fprintf(fidTeX,'\\begin{center}\n');
-fprintf(fidTeX,'\\begin{longtable}{l|lcccccc} \n');
+fprintf(fidTeX,'\\begin{longtable}{llcccccc} \n');
 fprintf(fidTeX,['\\caption{Results from Metropolis-Hastings (' title ')}\n ']);
 fprintf(fidTeX,['\\label{Table:MHPosterior:' int2str(fnum)  '}\\\\\n']);
-fprintf(fidTeX,'\\hline\\hline \\\\ \n');
-fprintf(fidTeX,['  & Prior distribution & Prior mean  & Prior ' ...
-                's.d. & Posterior mean & Posterior s.d.  & HPD inf & HPD sup\\\\ \n']);
-fprintf(fidTeX,'\\hline \\endfirsthead \n');
-fprintf(fidTeX,['\\caption{(continued)}']);
-fprintf(fidTeX,['\\label{Table:MHPosterior:' int2str(fnum)  '}\\\\\n']);
-fprintf(fidTeX,'\\hline\\hline \\\\ \n');
-fprintf(fidTeX,['  & Prior distribution & Prior mean  & Prior ' ...
-                's.d. & Posterior mean & Posterior s.d.  & HPD inf & HPD sup\\\\ \n']);
-fprintf(fidTeX,'\\hline \\endhead \n');
+fprintf(fidTeX,'\\toprule \n');
+fprintf(fidTeX,'  & \\multicolumn{3}{c}{Prior}  &  \\multicolumn{4}{c}{Posterior} \\\\\n');
+fprintf(fidTeX,'  \\cmidrule(r{.75em}){2-4} \\cmidrule(r{.75em}){5-8}\n');
+fprintf(fidTeX,'  & Dist. & Mean  & Stdev. & Mean & Stdev. & HPD inf & HPD sup\\\\\n');
+fprintf(fidTeX,'\\midrule \\endfirsthead \n');
+fprintf(fidTeX,['\\caption{(continued)}\\\\']);
+fprintf(fidTeX,'\\toprule \n');
+fprintf(fidTeX,'  & \\multicolumn{3}{c}{Prior}  &  \\multicolumn{4}{c}{Posterior} \\\\\n');
+fprintf(fidTeX,'  \\cmidrule(r{.75em}){2-4} \\cmidrule(r{.75em}){5-8}\n');
+fprintf(fidTeX,'  & Dist. & Mean  & Stdev. & Mean & Stdev. & HPD inf & HPD sup\\\\\n');
+fprintf(fidTeX,'\\midrule \\endhead \n');
 
-fprintf(fidTeX,'\\hline \\multicolumn{8}{r}{(Continued on next page)} \\\\ \\hline \\endfoot \n');
-fprintf(fidTeX,'\\hline \\hline \\endlastfoot \n');
+fprintf(fidTeX,'\\bottomrule \\multicolumn{8}{r}{(Continued on next page)} \\endfoot \n');
+fprintf(fidTeX,'\\bottomrule \\endlastfoot \n');
 
 
 fid = fidTeX;
 
 
 function TeXCore(fid,name,shape,priormean,priorstd,postmean,poststd,hpd)
-fprintf(fid,['$%s$ & %s & %7.3f & %6.4f & %7.3f& %6.4f & %7.4f & %7.4f \\\\ \n'],... 
+fprintf(fid,['$%s$ & %s & %7.3f & %6.4f & %7.3f& %6.4f & %7.4f & %7.4f \\\\ \n'],...
         name,...
         shape,...
         priormean,...
@@ -370,24 +371,25 @@ fprintf(fid,['$%s$ & %s & %7.3f & %6.4f & %7.3f& %6.4f & %7.4f & %7.4f \\\\ \n']
 
 
 function TeXEnd(fid,fnum,title)
-fprintf(fid,'\\end{longtable}\n ');    
+fprintf(fid,'\\end{longtable}\n ');
 fprintf(fid,'\\end{center}\n');
 fprintf(fid,'%% End of TeX file.\n');
 fclose(fid);
 
 
 function oo = Filloo(oo,name,type,postmean,hpdinterval,postmedian,postvar,postdecile,density)
-eval(['oo.posterior_mean.' type '.' name ' = postmean;']);
-eval(['oo.posterior_hpdinf.' type '.' name ' = hpdinterval(1);']); 
-eval(['oo.posterior_hpdsup.' type '.' name ' = hpdinterval(2);']);      
-eval(['oo.posterior_median.' type '.' name ' = postmedian;']);
-eval(['oo.posterior_variance.' type '.' name ' = postvar;']);
-eval(['oo.posterior_deciles.' type '.' name ' = postdecile;']);
-eval(['oo.posterior_density.' type '.' name ' = density;']);
+oo.posterior_mean.(type).(name) = postmean;
+oo.posterior_hpdinf.(type).(name) = hpdinterval(1);
+oo.posterior_hpdsup.(type).(name) = hpdinterval(2);
+oo.posterior_median.(type).(name) = postmedian;
+oo.posterior_variance.(type).(name) = postvar;
+oo.posterior_std.(type).(name) = sqrt(postvar);
+oo.posterior_deciles.(type).(name) = postdecile;
+oo.posterior_density.(type).(name) = density;
 
 function [post_mean,hpd_interval,post_var] = Extractoo(oo,name,type)
 hpd_interval = zeros(2,1);
-eval(['post_mean = oo.posterior_mean.' type '.' name ';']);
-eval(['hpd_interval(1) = oo.posterior_hpdinf.' type '.' name ';']); 
-eval(['hpd_interval(2) = oo.posterior_hpdsup.' type '.' name ';']);
-eval(['post_var = oo.posterior_variance.' type '.' name ';']);
\ No newline at end of file
+post_mean = oo.posterior_mean.(type).(name);
+hpd_interval(1) = oo.posterior_hpdinf.(type).(name);
+hpd_interval(2) = oo.posterior_hpdsup.(type).(name);
+post_var = oo.posterior_variance.(type).(name);
\ No newline at end of file
