@@ -1,20 +1,20 @@
 function varlist = check_list_of_variables(options_, M_, varlist)
 % This function defines, if necessary, the list of endogenous variables
-% for which the posterior statistics have to be computed. 
-% 
+% for which the posterior statistics have to be computed.
 %
-% INPUTS 
+%
+% INPUTS
 %
 %   options_        [structure]    Dynare structure.
 %   M_              [structure]    Dynare structure (related to model definition).
 %   varlist         [string]       Array of strings with name of the endogenous variables.
-%    
-% OUTPUTS 
-%   varlist         [string] 
-%        
+%
+% OUTPUTS
+%   varlist         [string]
+%
 % SPECIAL REQUIREMENTS
 
-% Copyright (C) 2003-2014 Dynare Team
+% Copyright (C) 2003-2017 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -31,6 +31,11 @@ function varlist = check_list_of_variables(options_, M_, varlist)
 % You should have received a copy of the GNU General Public License
 % along with Dynare.  If not, see <http://www.gnu.org/licenses/>.
 
+%get uniques
+
+[junk1,junk2,index_uniques] = varlist_indices(varlist,M_.endo_names);
+varlist=varlist(index_uniques,:);
+
 msg = 0;
 if options_.dsge_var && options_.bayesian_irf
     if ~isempty(varlist)
@@ -41,7 +46,7 @@ if options_.dsge_var && options_.bayesian_irf
                 msg = 1;
             end
         end
-        if size(varlist,1)~=size(options_.varobs)
+        if size(varlist,1)~=length(options_.varobs)
             msg = 1;
         end
         if msg
@@ -50,11 +55,21 @@ if options_.dsge_var && options_.bayesian_irf
             skipline()
         end
     end
-    varlist = options_.varobs;
+    varlist = char(options_.varobs);
     return
 end
 
-if isempty(varlist)
+if ~isempty(varlist) && ~isempty(options_.endo_vars_for_moment_computations_in_estimation)
+    error('You cannot use the consider_all_endogenous or consider_all_observed options when listing variables after the estimation command')
+elseif isempty(varlist) && ~isempty(options_.endo_vars_for_moment_computations_in_estimation)
+    if strcmp(options_.endo_vars_for_moment_computations_in_estimation,'all_endogenous_variables')
+        varlist = M_.endo_names(1:M_.orig_endo_nbr, :);
+    elseif strcmp(options_.endo_vars_for_moment_computations_in_estimation,'only_observed_variables')
+        varlist = char(options_.varobs');
+    else
+        error('Unknown option')
+    end
+elseif isempty(varlist) && isempty(options_.endo_vars_for_moment_computations_in_estimation)
     skipline()
     disp(['You did not declare endogenous variables after the estimation/calib_smoother command.'])
     cas = [];
@@ -91,7 +106,7 @@ if isempty(varlist)
     end
     if ~isempty(cas)
         string = [ cas , ' will be computed for the ' num2str(M_.endo_nbr)  ' endogenous variables'];
-        string = [ string ' of your model, this can be very long....']; 
+        string = [ string ' of your model, this can be very long....'];
         format_text(string, 10)
         if options_.nointeractive
             % Default behaviour is to consider all the endogenous variables.
@@ -113,7 +128,7 @@ if isempty(varlist)
                 if choice==1
                     varlist = M_.endo_names(1:M_.orig_endo_nbr, :);
                 elseif choice==2
-                    varlist = options_.varobs;
+                    varlist = char(options_.varobs);
                 elseif choice==3
                     varlist = NaN;
                 else
@@ -123,15 +138,14 @@ if isempty(varlist)
                 end
             end
         end
+        if isnan(varlist)
+            edit([M_.fname '.mod'])
+        end
+        skipline()
     end
-    if isnan(varlist)
-        edit([M_.fname '.mod'])
-    end
-    skipline()
 end
 
 
-
 function format_text(remain, max_number_of_words_per_line)
 index = 0;
 line_of_text = [];
