@@ -4,7 +4,7 @@ function h = dyn_waitbar(prctdone, varargin)
 % octave and when console_mode=1
 
 %
-% Copyright (C) 2011 Dynare Team
+% Copyright (C) 2011-2017 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -30,7 +30,7 @@ if iscell(prctdone)
     prctdone=prctdone{1};
 end
 
-if prctdone==0,
+if prctdone==0
     init=1;
     if isempty(whoiam)
         whoiam=0;
@@ -38,23 +38,20 @@ if prctdone==0,
 else
     init=0;
 end
-if nargout,
+if nargout
     h=[];
 end
 
 if ~whoiam
-    
     if isoctave || options_.console_mode
-                
-        if init,
+        if init
             diary off;
             running_text = varargin{1};
             newString='';
-            return;
-        elseif nargin>2,
+            return
+        elseif nargin>2
             running_text =  varargin{2};
         end
-        
         if isoctave
             printf([running_text,' %3.f%% done\r'], prctdone*100);
         else
@@ -62,26 +59,23 @@ if ~whoiam
             newString=sprintf([running_text,' %3.f%% done'], prctdone*100);
             fprintf([s0,'%s'],newString);
         end
-        
     else
-        if nargout,
+        if nargout
             h = waitbar(prctdone,varargin{:});
         else
             waitbar(prctdone,varargin{:});
         end
     end
-    
 else
-    if init,
+    if init
         running_text = varargin{1};
     elseif nargin>2
         running_text = varargin{2};
     end
-    if Parallel.Local,
+    if Parallel.Local
         waitbarTitle=['Local '];
     else
         waitbarTitle=[Parallel.ComputerName];
     end
     fMessageStatus(prctdone,whoiam,running_text, waitbarTitle, Parallel);
 end
-
