@@ -32,13 +32,10 @@ function x0 = stab_map_(OutputDirectoryName,opt_gsa)
 %
 % Written by Marco Ratto
 % Joint Research Centre, The European Commission,
-% (http://eemc.jrc.ec.europa.eu/),
-% marco.ratto@jrc.it
-%
-% Reference:
-% M. Ratto, Global Sensitivity Analysis for Macroeconomic models, MIMEO, 2006.
+% marco.ratto@ec.europa.eu
 
-% Copyright (C) 2012-2013 Dynare Team
+% Copyright (C) 2012-2016 European Commission
+% Copyright (C) 2012-2017 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -62,7 +59,6 @@ global bayestopt_ estim_params_ options_ oo_ M_
 
 Nsam   = opt_gsa.Nsam;
 fload  = opt_gsa.load_stab;
-ksstat = opt_gsa.ksstat;
 alpha2 = opt_gsa.alpha2_stab;
 pvalue_ks = opt_gsa.pvalue_ks;
 pvalue_corr = opt_gsa.pvalue_corr;
@@ -87,7 +83,7 @@ nshock = estim_params_.nvx;
 nshock = nshock + estim_params_.nvn;
 nshock = nshock + estim_params_.ncx;
 nshock = nshock + estim_params_.ncn;
-lpmat0=[];
+lpmat0=zeros(Nsam,0);
 xparam1=[];
 
 pshape = bayestopt_.pshape(nshock+1:end);
@@ -96,22 +92,63 @@ p2 = bayestopt_.p2(nshock+1:end);
 p3 = bayestopt_.p3(nshock+1:end);
 p4 = bayestopt_.p4(nshock+1:end);
 
-if nargin==0,
+[junk1,junk2,junk3,lb,ub,junk4] = set_prior(estim_params_,M_,options_); %Prepare bounds
+if ~isempty(bayestopt_) && any(bayestopt_.pshape > 0)
+    % Set prior bounds
+    bounds = prior_bounds(bayestopt_, options_.prior_trunc);
+    bounds.lb = max(bounds.lb,lb);
+    bounds.ub = min(bounds.ub,ub);
+else  % estimated parameters but no declared priors
+      % No priors are declared so Dynare will estimate the model by
+      % maximum likelihood with inequality constraints for the parameters.
+    bounds.lb = lb;
+    bounds.ub = ub;
+    if opt_gsa.prior_range==0
+        warning('GSA:: When using ML, sampling from the prior is not possible. Setting prior_range=1')
+        opt_gsa.prior_range=1;
+    end
+end
+
+if nargin==0
     OutputDirectoryName='';
 end
 
+options_mcf.pvalue_ks = pvalue_ks;
+options_mcf.pvalue_corr = pvalue_corr;
+options_mcf.alpha2 = alpha2;
+
+name=cell(np,1);
+name_tex=cell(np,1);
+for jj=1:np
+    if options_.TeX
+        [param_name_temp, param_name_tex_temp]= get_the_name(nshock+jj,options_.TeX,M_,estim_params_,options_);
+        name_tex{jj,1} = strrep(param_name_tex_temp,'$','');
+        name{jj,1} = param_name_temp;
+    else
+        param_name_temp = get_the_name(nshock+jj,options_.TeX,M_,estim_params_,options_);
+        name{jj,1} = param_name_temp;
+    end
+end
+if options_.TeX
+    options_mcf.param_names_tex=char(name_tex);
+end
+options_mcf.param_names = char(name);
+
+options_mcf.fname_ = fname_;
+options_mcf.OutputDirectoryName = OutputDirectoryName;
+options_mcf.xparam1 = [];
+
 opt=options_;
 options_.periods=0;
 options_.nomoments=1;
 options_.irf=0;
 options_.noprint=1;
-options_.simul=0;
-if fload==0,
+if fload==0
     %   if prepSA
     %     T=zeros(size(dr_.ghx,1),size(dr_.ghx,2)+size(dr_.ghu,2),Nsam/2);
     %   end
 
-    if isfield(dr_,'ghx'),
+    if isfield(dr_,'ghx')
         egg=zeros(length(dr_.eigval),Nsam);
     end
     yys=zeros(length(dr_.ys),Nsam);
@@ -122,42 +159,42 @@ if fload==0,
         Nsam=size(lpmat,1);
         lpmat0 = lpmat(:,1:nshock);
         lpmat = lpmat(:,nshock+1:end);
-%     elseif opt_gsa.morris==3,
-%         lpmat = prep_ide(Nsam,np,5);
-%         Nsam=size(lpmat,1);
+        %     elseif opt_gsa.morris==3,
+        %         lpmat = prep_ide(Nsam,np,5);
+        %         Nsam=size(lpmat,1);
     else
-        if np<52 && ilptau>0,
+        if np<52 && ilptau>0
             [lpmat] = qmc_sequence(np, int64(1), 0, Nsam)';
-            if np>30 || ilptau==2, % scrambled lptau
-                for j=1:np,
+            if np>30 || ilptau==2 % scrambled lptau
+                for j=1:np
                     lpmat(:,j)=lpmat(randperm(Nsam),j);
                 end
             end
         else %ilptau==0
-            %[lpmat] = rand(Nsam,np);
-            for j=1:np,
+            [lpmat] = NaN(Nsam,np);
+            for j=1:np
                 lpmat(:,j) = randperm(Nsam)'./(Nsam+1); %latin hypercube
             end
 
         end
     end
     %   try
-    dummy=prior_draw_gsa(1);
-    %   catch
-    %     if pprior,
-    %       if opt_gsa.prior_range==0;
-    %         error('Some unknown prior is specified or ML estimation,: use prior_range=1 option!!');
-    %       end
-    %     end
-    %
-    %   end
-    if pprior,
-        for j=1:nshock,
-            if opt_gsa.morris~=1,
+    dummy=prior_draw_gsa(1); %initialize persistent variables
+                             %   catch
+                             %     if pprior,
+                             %       if opt_gsa.prior_range==0;
+                             %         error('Some unknown prior is specified or ML estimation,: use prior_range=1 option!!');
+                             %       end
+                             %     end
+                             %
+                             %   end
+    if pprior
+        for j=1:nshock
+            if opt_gsa.morris~=1
                 lpmat0(:,j) = randperm(Nsam)'./(Nsam+1); %latin hypercube
             end
             if opt_gsa.prior_range
-                lpmat0(:,j)=lpmat0(:,j).*(bayestopt_.ub(j)-bayestopt_.lb(j))+bayestopt_.lb(j);
+                lpmat0(:,j)=lpmat0(:,j).*(bounds.ub(j)-bounds.lb(j))+bounds.lb(j);
             end
         end
         if opt_gsa.prior_range
@@ -167,8 +204,8 @@ if fload==0,
             %           xdelt(:,:,j)=prior_draw_gsa(0,[lpmat0 lpmat]+deltx);
             %         end
             %       end
-            for j=1:np,
-                lpmat(:,j)=lpmat(:,j).*(bayestopt_.ub(j+nshock)-bayestopt_.lb(j+nshock))+bayestopt_.lb(j+nshock);
+            for j=1:np
+                lpmat(:,j)=lpmat(:,j).*(bounds.ub(j+nshock)-bounds.lb(j+nshock))+bounds.lb(j+nshock);
             end
         else
             xx=prior_draw_gsa(0,[lpmat0 lpmat]);
@@ -217,24 +254,37 @@ if fload==0,
         %             end
         %         end
         %load([fname_,'_mode'])
-        eval(['load ' options_.mode_file '.mat;']);
-        if neighborhood_width>0,
-            for j=1:nshock,
-                lpmat0(:,j) = randperm(Nsam)'./(Nsam+1); %latin hypercube
-                ub=min([bayestopt_.ub(j) xparam1(j)*(1+neighborhood_width)]);
-                lb=max([bayestopt_.lb(j) xparam1(j)*(1-neighborhood_width)]);
+        if neighborhood_width>0 && isempty(options_.mode_file)
+            xparam1 = get_all_parameters(estim_params_,M_);
+        else
+            eval(['load ' options_.mode_file '.mat;']);
+        end
+        if neighborhood_width>0
+            for j=1:nshock
+                if opt_gsa.morris ~= 1
+                    lpmat0(:,j) = randperm(Nsam)'./(Nsam+1); %latin hypercube
+                end
+                ub=min([bounds.ub(j) xparam1(j)*(1+neighborhood_width)]);
+                lb=max([bounds.lb(j) xparam1(j)*(1-neighborhood_width)]);
                 lpmat0(:,j)=lpmat0(:,j).*(ub-lb)+lb;
             end
-            for j=1:np,
-                ub=min([bayestopt_.ub(j+nshock) xparam1(j+nshock)*(1+neighborhood_width)]);
-                lb=max([bayestopt_.lb(j+nshock) xparam1(j+nshock)*(1-neighborhood_width)]);
+            for j=1:np
+                ub=xparam1(j+nshock)*(1+sign(xparam1(j+nshock))*neighborhood_width);
+                lb=xparam1(j+nshock)*(1-sign(xparam1(j+nshock))*neighborhood_width);
+                if bounds.ub(j+nshock)>=xparam1(j) && bounds.lb(j)<=xparam1(j+nshock)
+                    ub=min([bounds.ub(j+nshock) ub]);
+                    lb=max([bounds.lb(j+nshock) lb]);
+                else
+                    fprintf('\nstab_map_:: the calibrated value of param %s for neighborhood_width sampling is outside prior bounds.\nWe allow violation of bounds for this parameter, but if this was not done on purpose, please change calibration before running neighborhood_width sampling\n', bayestopt_.name{j+nshock})
+                end
                 lpmat(:,j)=lpmat(:,j).*(ub-lb)+lb;
             end
         else
             d = chol(inv(hh));
             lp=randn(Nsam*2,nshock+np)*d+kron(ones(Nsam*2,1),xparam1');
-            for j=1:Nsam*2,
-                lnprior(j) = any(lp(j,:)'<=bayestopt_.lb | lp(j,:)'>=bayestopt_.ub);
+            lnprior=zeros(1,Nsam*2);
+            for j=1:Nsam*2
+                lnprior(j) = any(lp(j,:)'<=bounds.lb | lp(j,:)'>=bounds.ub);
             end
             ireal=[1:2*Nsam];
             ireal=ireal(find(lnprior==0));
@@ -252,23 +302,27 @@ if fload==0,
     iunstable=[1:Nsam];
     iindeterm=zeros(1,Nsam);
     iwrong=zeros(1,Nsam);
-    for j=1:Nsam,
-        M_.params(estim_params_.param_vals(:,1)) = lpmat(j,:)';
+    inorestriction=zeros(1,Nsam);
+    irestriction=zeros(1,Nsam);
+    infox=zeros(Nsam,1);
+    for j=1:Nsam
+        M_ = set_all_parameters([lpmat0(j,:) lpmat(j,:)]',estim_params_,M_);
         %try stoch_simul([]);
         try
-            [Tt,Rr,SteadyState,info,M_,options_,oo_] = dynare_resolve(M_,options_,oo_,'restrict');
-            if info(1)==0,
-                info=endogenous_prior_restrictions(Tt,Rr,M_,options_,oo_);
+            if ~ isempty(options_.endogenous_prior_restrictions.moment)
+                [Tt,Rr,SteadyState,info,M_,options_,oo_] = dynare_resolve(M_,options_,oo_);
+            else
+                [Tt,Rr,SteadyState,info,M_,options_,oo_] = dynare_resolve(M_,options_,oo_,'restrict');
             end
             infox(j,1)=info(1);
-            if infox(j,1)==0 && ~exist('T'),
+            if infox(j,1)==0 && ~exist('T','var')
                 dr_=oo_.dr;
-                if prepSA,
+                if prepSA
                     try
                         T=zeros(size(dr_.ghx,1),size(dr_.ghx,2)+size(dr_.ghu,2),Nsam);
                     catch
                         ME = lasterror();
-                        if strcmp('MATLAB:nomem',ME.identifier),
+                        if strcmp('MATLAB:nomem',ME.identifier)
                             prepSA=0;
                             disp('The model is too large for storing state space matrices ...')
                             disp('for mapping reduced form or for identification')
@@ -280,28 +334,27 @@ if fload==0,
                 end
                 egg=zeros(length(dr_.eigval),Nsam);
             end
-            if infox(j,1),
-%                 disp('no solution'),
-                if isfield(oo_.dr,'ghx'),
+            if infox(j,1)
+                %                 disp('no solution'),
+                if isfield(oo_.dr,'ghx')
                     oo_.dr=rmfield(oo_.dr,'ghx');
                 end
-                if (infox(j,1)<3 || infox(j,1)>5) && isfield(oo_.dr,'eigval'),
+                if (infox(j,1)<3 || infox(j,1)>5) && isfield(oo_.dr,'eigval')
                     oo_.dr=rmfield(oo_.dr,'eigval');
                 end
             end
         catch ME
-            if isfield(oo_.dr,'eigval'),
+            if isfield(oo_.dr,'eigval')
                 oo_.dr=rmfield(oo_.dr,'eigval');
             end
-            if isfield(oo_.dr,'ghx'),
+            if isfield(oo_.dr,'ghx')
                 oo_.dr=rmfield(oo_.dr,'ghx');
             end
-            disp('No solution could be found'),
+            disp('No solution could be found')
         end
         dr_ = oo_.dr;
-        if isfield(dr_,'ghx'),
+        if isfield(dr_,'ghx')
             egg(:,j) = sort(dr_.eigval);
-            iunstable(j)=0;
             if prepSA
                 jstab=jstab+1;
                 T(:,:,jstab) = [dr_.ghx dr_.ghu];
@@ -310,26 +363,34 @@ if fload==0,
                 %           bayestopt_.restrict_columns, ...
                 %           bayestopt_.restrict_aux);
             end
-            if ~exist('nspred'),
+            if ~exist('nspred','var')
                 nspred = dr_.nspred; %size(dr_.ghx,2);
                 nboth = dr_.nboth;
                 nfwrd = dr_.nfwrd;
             end
+            info=endogenous_prior_restrictions(Tt,Rr,M_,options_,oo_);
+            infox(j,1)=info(1);
+            if info(1)
+                inorestriction(j)=j;
+            else
+                iunstable(j)=0;
+                irestriction(j)=j;
+            end
         else
             istable(j)=0;
             if isfield(dr_,'eigval')
                 egg(:,j) = sort(dr_.eigval);
-                if exist('nspred')
+                if exist('nspred','var')
                     if any(isnan(egg(1:nspred,j)))
                         iwrong(j)=j;
                     else
-                        if (nboth || nfwrd) && abs(egg(nspred+1,j))<=options_.qz_criterium,
+                        if (nboth || nfwrd) && abs(egg(nspred+1,j))<=options_.qz_criterium
                             iindeterm(j)=j;
                         end
                     end
                 end
             else
-                if exist('egg'),
+                if exist('egg','var')
                     egg(:,j)=ones(size(egg,1),1).*NaN;
                 end
                 iwrong(j)=j;
@@ -341,15 +402,18 @@ if fload==0,
         dyn_waitbar(j/Nsam,h,['MC iteration ',int2str(j),'/',int2str(Nsam)])
     end
     dyn_waitbar_close(h);
-    if prepSA && jstab,
+    if prepSA && jstab
         T=T(:,:,1:jstab);
     else
         T=[];
     end
-    istable=istable(find(istable));  % stable params
-    iunstable=iunstable(find(iunstable));   % unstable params
+    istable=istable(find(istable));  % stable params ignoring restrictions
+    irestriction=irestriction(find(irestriction));  % stable params & restrictions OK
+    inorestriction=inorestriction(find(inorestriction));  % stable params violating restrictions
+    iunstable=iunstable(find(iunstable));   % violation of BK & restrictions & solution could not be found (whatever goes wrong)
     iindeterm=iindeterm(find(iindeterm));  % indeterminacy
     iwrong=iwrong(find(iwrong));  % dynare could not find solution
+    ixun=iunstable(find(~ismember(iunstable,[iindeterm,iwrong,inorestriction]))); % explosive roots
 
     %     % map stable samples
     %     istable=[1:Nsam];
@@ -390,42 +454,42 @@ if fload==0,
     bkpprior.p2=bayestopt_.p2;
     bkpprior.p3=bayestopt_.p3;
     bkpprior.p4=bayestopt_.p4;
-    if pprior,
+    if pprior
         if ~prepSA
             save([OutputDirectoryName filesep fname_ '_prior.mat'], ...
-                'bkpprior','lpmat','lpmat0','iunstable','istable','iindeterm','iwrong', ...
-                'egg','yys','nspred','nboth','nfwrd','infox')
+                 'bkpprior','lpmat','lpmat0','irestriction','iunstable','istable','iindeterm','iwrong','ixun', ...
+                 'egg','yys','nspred','nboth','nfwrd','infox')
         else
             save([OutputDirectoryName filesep fname_ '_prior.mat'], ...
-                'bkpprior','lpmat','lpmat0','iunstable','istable','iindeterm','iwrong', ...
-                'egg','yys','T','nspred','nboth','nfwrd','infox')
+                 'bkpprior','lpmat','lpmat0','irestriction','iunstable','istable','iindeterm','iwrong','ixun', ...
+                 'egg','yys','T','nspred','nboth','nfwrd','infox')
         end
 
     else
         if ~prepSA
             save([OutputDirectoryName filesep fname_ '_mc.mat'], ...
-                'lpmat','lpmat0','iunstable','istable','iindeterm','iwrong', ...
-                'egg','yys','nspred','nboth','nfwrd','infox')
+                 'lpmat','lpmat0','irestriction','iunstable','istable','iindeterm','iwrong','ixun', ...
+                 'egg','yys','nspred','nboth','nfwrd','infox')
         else
             save([OutputDirectoryName filesep fname_ '_mc.mat'], ...
-                'lpmat','lpmat0','iunstable','istable','iindeterm','iwrong', ...
-                'egg','yys','T','nspred','nboth','nfwrd','infox')
+                 'lpmat','lpmat0','irestriction','iunstable','istable','iindeterm','iwrong','ixun', ...
+                 'egg','yys','T','nspred','nboth','nfwrd','infox')
         end
     end
 else
-    if pprior,
+    if pprior
         filetoload=[OutputDirectoryName filesep fname_ '_prior.mat'];
     else
         filetoload=[OutputDirectoryName filesep fname_ '_mc.mat'];
     end
-    load(filetoload,'lpmat','lpmat0','iunstable','istable','iindeterm','iwrong','egg','yys','nspred','nboth','nfwrd','infox')
+    load(filetoload,'lpmat','lpmat0','irestriction','iunstable','istable','iindeterm','iwrong','ixun','egg','yys','nspred','nboth','nfwrd','infox')
     Nsam = size(lpmat,1);
-    if pprior==0,
+    if pprior==0 && ~isempty(options_.mode_file)
         eval(['load ' options_.mode_file '.mat;']);
     end
 
 
-    if prepSA && isempty(strmatch('T',who('-file', filetoload),'exact')),
+    if prepSA && isempty(strmatch('T',who('-file', filetoload),'exact'))
         h = dyn_waitbar(0,'Please wait...');
         options_.periods=0;
         options_.nomoments=1;
@@ -434,7 +498,8 @@ else
         stoch_simul([]);
         %T=zeros(size(dr_.ghx,1),size(dr_.ghx,2)+size(dr_.ghu,2),length(istable));
         ntrans=length(istable);
-        for j=1:ntrans,
+        yys=NaN(length(ys_),ntrans);
+        for j=1:ntrans
             M_.params(estim_params_.param_vals(:,1)) = lpmat(istable(j),:)';
             %stoch_simul([]);
             [Tt,Rr,SteadyState,info,M_,options_,oo_] = dynare_resolve(M_,options_,oo_,'restrict');
@@ -442,12 +507,12 @@ else
             %[Tt,Rr,SteadyState,info] = dynare_resolve(bayestopt_.restrict_var_list,...
             %    bayestopt_.restrict_columns,...
             %    bayestopt_.restrict_aux);
-            if ~exist('T')
+            if ~exist('T','var')
                 T=zeros(size(dr_.ghx,1),size(dr_.ghx,2)+size(dr_.ghu,2),ntrans);
             end
             dr_ = oo_.dr;
             T(:,:,j) = [dr_.ghx dr_.ghu];
-            if ~exist('nspred')
+            if ~exist('nspred','var')
                 nspred = dr_.nspred; %size(dr_.ghx,2);
                 nboth = dr_.nboth;
                 nfwrd = dr_.nfwrd;
@@ -465,191 +530,177 @@ else
 end
 
 if pprior
-    % univariate
-    aname='prior_stab'; atitle='Prior StabMap: Parameter driving non-existence of unique stable solution (Unacceptable)';
-    aindetname=[aname, '_indet']; aindettitle='Prior StabMap: Parameter driving indeterminacy';
-    aunstablename=[aname, '_unst'];  aunstabletitle='Prior StabMap: Parameter driving explosiveness of solution';
-    awronguniname=[aname, '_wrong']; awrongunititle='Prior StabMap: Parameter driving inability to find solution';
-    % bivariate
-    auname='prior_unacceptable'; autitle='Prior StabMap: non-existence of unique stable solution (Unacceptable)';
     aunstname='prior_unstable'; aunsttitle='Prior StabMap: explosiveness of solution';
     aindname='prior_indeterm'; aindtitle='Prior StabMap: Indeterminacy';
     awrongname='prior_wrong'; awrongtitle='Prior StabMap: inability to find solution';
-    asname='prior_stable'; astitle='Prior StabMap: unique Stable Saddle-Path';
+    acalibname='prior_calib'; acalibtitle='Prior StabMap: IRF/moment restrictions';
+    asname='prior_stable'; atitle='Prior StabMap: Parameter driving non-existence of unique stable solution (Unacceptable)';
 else
-    % univariate
-    aname='mc_stab'; atitle='MC (around posterior mode) StabMap: Parameter driving non-existence of unique stable solution (Unacceptable)';
-    aindetname=[aname, '_indet']; aindettitle='MC (around posterior mode) StabMap: Parameter driving indeterminacy';
-    aunstablename=[aname, '_unst'];  aunstabletitle='MC (around posterior mode) StabMap: Parameter driving explosiveness of solution';
-    awronguniname=[aname, '_wrong']; awrongunititle='MC (around posterior mode) StabMap: Parameter driving inability to find solution';
-    % bivariate
-    auname='mc_unacceptable'; autitle='MC (around posterior mode) StabMap: non-existence of unique stable solution (Unacceptable)';
     aunstname='mc_unstable'; aunsttitle='MC (around posterior mode) StabMap: explosiveness of solution';
     aindname='mc_indeterm';  aindtitle='MC (around posterior mode) StabMap: Indeterminacy';
     awrongname='mc_wrong'; awrongtitle='MC (around posterior mode) StabMap: inability to find solution';
-    asname='mc_stable'; astitle='MC (around posterior mode) StabMap: Unique Stable Saddle-Path';
+    acalibname='mc_calib'; acalibtitle='MC (around posterior mode) StabMap: IRF/moment restrictions';
+    asname='mc_stable'; atitle='MC (around posterior mode) StabMap: Parameter driving non-existence of unique stable solution (Unacceptable)';
 end
-delete([OutputDirectoryName,filesep,fname_,'_',aname,'_*.*']);
-%delete([OutputDirectoryName,filesep,fname_,'_',aname,'_SA_*.*']);
-delete([OutputDirectoryName,filesep,fname_,'_',asname,'_corr_*.*']);
-delete([OutputDirectoryName,filesep,fname_,'_',auname,'_corr_*.*']);
-delete([OutputDirectoryName,filesep,fname_,'_',aunstname,'_corr_*.*']);
-delete([OutputDirectoryName,filesep,fname_,'_',aindname,'_corr_*.*']);
+delete([OutputDirectoryName,filesep,fname_,'_',asname,'.*']);
+delete([OutputDirectoryName,filesep,fname_,'_',acalibname,'.*']);
+delete([OutputDirectoryName,filesep,fname_,'_',aindname,'.*']);
+delete([OutputDirectoryName,filesep,fname_,'_',aunstname,'.*']);
+delete([OutputDirectoryName,filesep,fname_,'_',awrongname,'.*']);
 
-if length(iunstable)>0 && length(iunstable)<Nsam,
+if length(iunstable)>0 || length(iwrong)>0
     fprintf(['%4.1f%% of the prior support gives unique saddle-path solution.\n'],length(istable)/Nsam*100)
-    fprintf(['%4.1f%% of the prior support gives explosive dynamics.\n'],(length(iunstable)-length(iwrong)-length(iindeterm) )/Nsam*100)
-    if ~isempty(iindeterm),
-        fprintf(['%4.1f%% of the prior support gives indeterminacy.'],length(iindeterm)/Nsam*100)
+    fprintf(['%4.1f%% of the prior support gives explosive dynamics.\n'],(length(ixun) )/Nsam*100)
+    if ~isempty(iindeterm)
+        fprintf(['%4.1f%% of the prior support gives indeterminacy.\n'],length(iindeterm)/Nsam*100)
     end
-    if ~isempty(iwrong),
+    inorestriction = istable(find(~ismember(istable,irestriction))); % violation of prior restrictions
+    if ~isempty(iwrong) || ~isempty(inorestriction)
         skipline()
-        disp(['For ',num2str(length(iwrong)/Nsam*100,'%1.3f'),'\% of the prior support dynare could not find a solution.'])
-        skipline()
-        if any(infox==1),
-            disp(['    For ',num2str(length(find(infox==1))/Nsam*100,'%1.3f'),'\% The model doesn''t determine the current variables uniquely.'])
+        if any(infox==49)
+            fprintf(['%4.1f%% of the prior support violates prior restrictions.\n'],(length(inorestriction) )/Nsam*100)
         end
-        if any(infox==2),
-            disp(['    For ',num2str(length(find(infox==2))/Nsam*100,'%1.3f'),'\% MJDGGES returned an error code.'])
+        if ~isempty(iwrong)
+            skipline()
+            disp(['For ',num2str(length(iwrong)/Nsam*100,'%4.1f'),'% of the prior support dynare could not find a solution.'])
+            skipline()
         end
-        if any(infox==6),
-            disp(['    For ',num2str(length(find(infox==6))/Nsam*100,'%1.3f'),'\% The jacobian evaluated at the deterministic steady state is complex.'])
+        if any(infox==1)
+            disp(['    For ',num2str(length(find(infox==1))/Nsam*100,'%4.1f'),'% The model doesn''t determine the current variables uniquely.'])
         end
-        if any(infox==19),
-            disp(['    For ',num2str(length(find(infox==19))/Nsam*100,'%1.3f'),'\% The steadystate routine thrown an exception (inconsistent deep parameters).'])
+        if any(infox==2)
+            disp(['    For ',num2str(length(find(infox==2))/Nsam*100,'%4.1f'),'% MJDGGES returned an error code.'])
         end
-        if any(infox==20),
-            disp(['    For ',num2str(length(find(infox==20))/Nsam*100,'%1.3f'),'\% Cannot find the steady state.'])
+        if any(infox==6)
+            disp(['    For ',num2str(length(find(infox==6))/Nsam*100,'%4.1f'),'% The jacobian evaluated at the deterministic steady state is complex.'])
         end
-        if any(infox==21),
-            disp(['    For ',num2str(length(find(infox==21))/Nsam*100,'%1.3f'),'\% The steady state is complex.'])
+        if any(infox==19)
+            disp(['    For ',num2str(length(find(infox==19))/Nsam*100,'%4.1f'),'% The steadystate routine thrown an exception (inconsistent deep parameters).'])
         end
-        if any(infox==22),
-            disp(['    For ',num2str(length(find(infox==22))/Nsam*100,'%1.3f'),'\% The steady has NaNs.'])
+        if any(infox==20)
+            disp(['    For ',num2str(length(find(infox==20))/Nsam*100,'%4.1f'),'% Cannot find the steady state.'])
         end
-        if any(infox==23),
-            disp(['    For ',num2str(length(find(infox==23))/Nsam*100,'%1.3f'),'\% M_.params has been updated in the steadystate routine and has complex valued scalars.'])
+        if any(infox==21)
+            disp(['    For ',num2str(length(find(infox==21))/Nsam*100,'%4.1f'),'% The steady state is complex.'])
         end
-        if any(infox==24),
-            disp(['    For ',num2str(length(find(infox==24))/Nsam*100,'%1.3f'),'\% M_.params has been updated in the steadystate routine and has some NaNs.'])
+        if any(infox==22)
+            disp(['    For ',num2str(length(find(infox==22))/Nsam*100,'%4.1f'),'% The steady has NaNs.'])
         end
-        if any(infox==30),
-            disp(['    For ',num2str(length(find(infox==30))/Nsam*100,'%1.3f'),'\% Ergodic variance can''t be computed.'])
+        if any(infox==23)
+            disp(['    For ',num2str(length(find(infox==23))/Nsam*100,'%4.1f'),'% M_.params has been updated in the steadystate routine and has complex valued scalars.'])
         end
-        if any(infox==49),
-            disp(['    For ',num2str(length(find(infox==49))/Nsam*100,'%1.3f'),'\% The model violates one (many) endogenous prior restriction(s).'])
+        if any(infox==24)
+            disp(['    For ',num2str(length(find(infox==24))/Nsam*100,'%4.1f'),'% M_.params has been updated in the steadystate routine and has some NaNs.'])
+        end
+        if any(infox==30)
+            disp(['    For ',num2str(length(find(infox==30))/Nsam*100,'%4.1f'),'% Ergodic variance can''t be computed.'])
         end
 
     end
     skipline()
-    % Blanchard Kahn
-    [proba, dproba] = stab_map_1(lpmat, istable, iunstable, aname,0);
-%     indstab=find(dproba>ksstat);
-    indstab=find(proba<pvalue_ks);
-    disp('Smirnov statistics in driving acceptable behaviour')
-    for j=1:length(indstab),
-        disp([M_.param_names(estim_params_.param_vals(indstab(j),1),:),'   d-stat = ', num2str(dproba(indstab(j)),'%1.3f'),'   p-value = ', num2str(proba(indstab(j)),'%1.3f')])
-    end
-    skipline()
-    if ~isempty(indstab)
-        stab_map_1(lpmat, istable, iunstable, aname, 1, indstab, OutputDirectoryName,[],atitle);
-    end
-    ixun=iunstable(find(~ismember(iunstable,[iindeterm,iwrong])));
-    if ~isempty(iindeterm),
-        [proba, dproba] = stab_map_1(lpmat, [1:Nsam], iindeterm, aindetname ,0);
-%         indindet=find(dproba>ksstat);
-        indindet=find(proba<pvalue_ks);
-        disp('Smirnov statistics in driving indeterminacy')
-        for j=1:length(indindet),
-            disp([M_.param_names(estim_params_.param_vals(indindet(j),1),:),'   d-stat = ', num2str(dproba(indindet(j)),'%1.3f'),'   p-value = ', num2str(proba(indindet(j)),'%1.3f')])
+    if length(iunstable)<Nsam || length(istable)>1
+        itot = [1:Nsam];
+        isolve = itot(find(~ismember(itot,iwrong))); % dynare could find a solution
+                                                     % Blanchard Kahn
+        if neighborhood_width
+            options_mcf.xparam1 = xparam1(nshock+1:end);
         end
-        skipline()
-        if ~isempty(indindet)
-            stab_map_1(lpmat, [1:Nsam], iindeterm, aindetname, 1, indindet, OutputDirectoryName,[],aindettitle);
+        itmp = itot(find(~ismember(itot,istable)));
+        options_mcf.amcf_name = asname;
+        options_mcf.amcf_title = atitle;
+        options_mcf.beha_title = 'unique Stable Saddle-Path';
+        options_mcf.nobeha_title = 'NO unique Stable Saddle-Path';
+        options_mcf.title = 'unique solution';
+        mcf_analysis(lpmat, istable, itmp, options_mcf, options_);
+
+        if ~isempty(iindeterm)
+            itmp = isolve(find(~ismember(isolve,iindeterm)));
+            options_mcf.amcf_name = aindname;
+            options_mcf.amcf_title = aindtitle;
+            options_mcf.beha_title = 'NO indeterminacy';
+            options_mcf.nobeha_title = 'indeterminacy';
+            options_mcf.title = 'indeterminacy';
+            mcf_analysis(lpmat, itmp, iindeterm, options_mcf, options_);
         end
-    end
 
-    if ~isempty(ixun),
-        [proba, dproba] = stab_map_1(lpmat, [1:Nsam], ixun, aunstablename,0);
-%         indunst=find(dproba>ksstat);
-        indunst=find(proba<pvalue_ks);
-        disp('Smirnov statistics in driving instability')
-        for j=1:length(indunst),
-            disp([M_.param_names(estim_params_.param_vals(indunst(j),1),:),'   d-stat = ', num2str(dproba(indunst(j)),'%1.3f'),'   p-value = ', num2str(proba(indunst(j)),'%1.3f')])
+        if ~isempty(ixun)
+            itmp = isolve(find(~ismember(isolve,ixun)));
+            options_mcf.amcf_name = aunstname;
+            options_mcf.amcf_title = aunsttitle;
+            options_mcf.beha_title = 'NO explosive solution';
+            options_mcf.nobeha_title = 'explosive solution';
+            options_mcf.title = 'instability';
+            mcf_analysis(lpmat, itmp, ixun, options_mcf, options_);
         end
-        skipline()
-        if ~isempty(indunst)
-            stab_map_1(lpmat, [1:Nsam], ixun, aunstablename, 1, indunst, OutputDirectoryName,[],aunstabletitle);
+
+        inorestriction = istable(find(~ismember(istable,irestriction))); % violation of prior restrictions
+        iwrong = iwrong(find(~ismember(iwrong,inorestriction))); % what went wrong beyond prior restrictions
+        if ~isempty(iwrong)
+            itmp = itot(find(~ismember(itot,iwrong)));
+            options_mcf.amcf_name = awrongname;
+            options_mcf.amcf_title = awrongtitle;
+            options_mcf.beha_title = 'NO inability to find a solution';
+            options_mcf.nobeha_title = 'inability to find a solution';
+            options_mcf.title = 'inability to find a solution';
+            mcf_analysis(lpmat, itmp, iwrong, options_mcf, options_);
         end
-    end
 
-    if ~isempty(iwrong),
-        [proba, dproba] = stab_map_1(lpmat, [1:Nsam], iwrong, awronguniname,0);
-%         indwrong=find(dproba>ksstat);
-        indwrong=find(proba<pvalue_ks);
-        disp('Smirnov statistics in driving no solution')
-        for j=1:length(indwrong),
-            disp([M_.param_names(estim_params_.param_vals(indwrong(j),1),:),'   d-stat = ', num2str(dproba(indwrong(j)),'%1.3f'),'   p-value = ', num2str(proba(indwrong(j)),'%1.3f')])
+        if ~isempty(irestriction)
+            if neighborhood_width
+                options_mcf.xparam1 = xparam1;
+            end
+            np=size(bayestopt_.name,1);
+            name=cell(np,1);
+            name_tex=cell(np,1);
+            for jj=1:np
+                if options_.TeX
+                    [param_name_temp, param_name_tex_temp]= get_the_name(jj,options_.TeX,M_,estim_params_,options_);
+                    name_tex{jj,1} = strrep(param_name_tex_temp,'$','');
+                    name{jj,1} = param_name_temp;
+                else
+                    param_name_temp = get_the_name(jj,options_.TeX,M_,estim_params_,options_);
+                    name{jj,1} = param_name_temp;
+                end
+            end
+            if options_.TeX
+                options_mcf.param_names_tex = char(name_tex);
+            end
+            options_mcf.param_names = char(name);
+            options_mcf.amcf_name = acalibname;
+            options_mcf.amcf_title = acalibtitle;
+            options_mcf.beha_title = 'prior IRF/moment calibration';
+            options_mcf.nobeha_title = 'NO prior IRF/moment calibration';
+            options_mcf.title = 'prior restrictions';
+            mcf_analysis([lpmat0 lpmat], irestriction, inorestriction, options_mcf, options_);
+            iok = irestriction(1);
+            x0 = [lpmat0(iok,:)'; lpmat(iok,:)'];
+        else
+            iok = istable(1);
+            x0=0.5.*(bounds.ub(1:nshock)-bounds.lb(1:nshock))+bounds.lb(1:nshock);
+            x0 = [x0; lpmat(iok,:)'];
         end
-        skipline()
-        if ~isempty(indwrong)
-            stab_map_1(lpmat, [1:Nsam], iwrong, awronguniname, 1, indwrong, OutputDirectoryName,[],awrongunititle);
-        end
-    end
 
-    skipline()
-    disp('Starting bivariate analysis:')
-
-    c0=corrcoef(lpmat(istable,:));
-    c00=tril(c0,-1);
-
-    if length(istable)>10,
-        stab_map_2(lpmat(istable,:),alpha2, pvalue_corr, asname, OutputDirectoryName,xparam1,astitle);
-    end
-    if length(iunstable)>10,
-        stab_map_2(lpmat(iunstable,:),alpha2, pvalue_corr, auname, OutputDirectoryName,xparam1,autitle);
-    end
-    if length(iindeterm)>10,
-        stab_map_2(lpmat(iindeterm,:),alpha2, pvalue_corr, aindname, OutputDirectoryName,xparam1,aindtitle);
-    end
-    if length(ixun)>10,
-        stab_map_2(lpmat(ixun,:),alpha2, pvalue_corr, aunstname, OutputDirectoryName,xparam1,aunsttitle);
-    end
-    if length(iwrong)>10,
-        stab_map_2(lpmat(iwrong,:),alpha2, pvalue_corr, awrongname, OutputDirectoryName,xparam1,awrongtitle);
-    end
-
-    x0=0.5.*(bayestopt_.ub(1:nshock)-bayestopt_.lb(1:nshock))+bayestopt_.lb(1:nshock);
-    x0 = [x0; lpmat(istable(1),:)'];
-    if istable(end)~=Nsam
-        M_.params(estim_params_.param_vals(:,1)) = lpmat(istable(1),:)';
+        M_ = set_all_parameters(x0,estim_params_,M_);
         [oo_.dr,info,M_,options_,oo_] = resol(0,M_,options_,oo_);
         %     stoch_simul([]);
-    end
-else
-    if length(iunstable)==0,
-        disp('All parameter values in the specified ranges give unique saddle-path solution!')
-        x0=0.5.*(bayestopt_.ub(1:nshock)-bayestopt_.lb(1:nshock))+bayestopt_.lb(1:nshock);
-        x0 = [x0; lpmat(istable(1),:)'];
     else
         disp('All parameter values in the specified ranges are not acceptable!')
         x0=[];
     end
+else
+    disp('All parameter values in the specified ranges give unique saddle-path solution,')
+    disp('and match prior IRF/moment restriction(s) if any!')
+    x0=0.5.*(bounds.ub(1:nshock)-bounds.lb(1:nshock))+bounds.lb(1:nshock);
+    x0 = [x0; lpmat(istable(1),:)'];
 
 end
 
 xparam1=x0;
-save prior_ok xparam1;
+save prior_ok.mat xparam1;
 
 options_.periods=opt.periods;
-if isfield(opt,'nomoments'),
+if isfield(opt,'nomoments')
     options_.nomoments=opt.nomoments;
 end
 options_.irf=opt.irf;
 options_.noprint=opt.noprint;
-if isfield(opt,'simul'),
-    options_.simul=opt.simul;
-end
-
-
-
