@@ -7,21 +7,21 @@ function [condJ, ind0, indnoJ, ixnoJ, McoJ, PcoJ, jweak, jweak_pair] = identific
 %                                 derivatives of output w.r.t. parameters and shocks
 %    o JJ               [matrix] [nparams x nparams] IF hess_flag==1
 %                                 information matrix
-%    
+%
 % OUTPUTS
 %    o cond             condition number of JJ
 %    o ind0             [array] binary indicator for non-zero columns of H
-%    o indnoJ           [matrix] index of non-identified params 
+%    o indnoJ           [matrix] index of non-identified params
 %    o ixnoJ            number of rows in indnoJ
 %    o Mco              [array] multicollinearity coefficients
-%    o Pco              [matrix] pairwise correlations 
+%    o Pco              [matrix] pairwise correlations
 %    o jweak            [binary array] gives 1 if the  parameter has Mco=1(with tolerance 1.e-10)
 %    o jweak_pair       [binary matrix] gives 1 if a couple parameters has Pco=1(with tolerance 1.e-10)
-%    
+%
 % SPECIAL REQUIREMENTS
 %    None
 
-% Copyright (C) 2008-2011 Dynare Team
+% Copyright (C) 2008-2017 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -45,27 +45,50 @@ function [condJ, ind0, indnoJ, ixnoJ, McoJ, PcoJ, jweak, jweak_pair] = identific
 npar = size(JJ,2);
 indnoJ = zeros(1,npar);
 
-if size(JJ,1)>1,
+if size(JJ,1)>1
     ind1 = find(vnorm(JJ)>=eps); % take non-zero columns
 else
     ind1 = find(abs(JJ)>=eps); % take non-zero columns
-end    
+end
 JJ1 = JJ(:,ind1);
 [eu,ee2,ee1] = svd( JJ1, 0 );
 condJ= cond(JJ1);
-rankJ = rank(JJ./norm(JJ),1.e-10);
+rankJ = rank(JJ);
 rankJJ = rankJ;
+icheck=0;
+if npar>0 && (rankJ<npar)
+    % search for singular values associated to ONE individual parameter
+    ee0 = [rankJJ+1:length(ind1)];
+    ind11=ones(length(ind1),1);
+    for j=1:length(ee0)
+        if length(find(abs(ee1(:,ee0(j))) > 1.e-3))==1
+            icheck=1;
+            ind11 = ind11.*(abs(ee1(:,ee0(j))) <= 1.e-3); % take non-zero columns
+        end
+    end
+    ind1 = ind1(find(ind11)); % take non-zero columns
+end
+
+if icheck
+    JJ1 = JJ(:,ind1);
+    [eu,ee2,ee1] = svd( JJ1, 0 );
+    condJ= cond(JJ1);
+    rankJ = rank(JJ);
+    rankJJ = rankJ;
+end
+
+
 % if hess_flag==0,
 %     rankJJ = rank(JJ'*JJ);
-% end   
+% end
 
 ind0 = zeros(1,npar);
 ind0(ind1) = 1;
 
-if hess_flag==0,
+if hess_flag==0
     % find near linear dependence problems:
     McoJ = NaN(npar,1);
-    for ii = 1:size(JJ1,2);
+    for ii = 1:size(JJ1,2)
         McoJ(ind1(ii),:) = cosn([JJ1(:,ii),JJ1(:,find([1:1:size(JJ1,2)]~=ii))]);
     end
 else
@@ -73,7 +96,7 @@ else
     tildaJ = JJ(ind1,ind1)./((deltaJ)*(deltaJ'));
     McoJ(ind1,1)=(1-1./diag(inv(tildaJ)));
     rhoM=sqrt(1-McoJ);
-%     PcoJ=inv(tildaJ);
+    %     PcoJ=inv(tildaJ);
     PcoJ=NaN(npar,npar);
     PcoJ(ind1,ind1)=inv(JJ(ind1,ind1));
     sd=sqrt(diag(PcoJ));
@@ -82,23 +105,21 @@ end
 
 
 ixnoJ = 0;
-if rankJ<npar || rankJJ<npar || min(1-McoJ)<1.e-10
+if npar>0 && (rankJ<npar || rankJJ<npar || min(1-McoJ)<1.e-10)
     %         - find out which parameters are involved
     %   disp('Some parameters are NOT identified by the moments included in J')
     %   disp(' ')
-    if length(ind1)<npar,
+    if length(ind1)<npar
         % parameters with zero column in JJ
         ixnoJ = ixnoJ + 1;
         indnoJ(ixnoJ,:) = (~ismember([1:npar],ind1));
     end
     ee0 = [rankJJ+1:length(ind1)];
-    for j=1:length(ee0),
+    for j=1:length(ee0)
         % linearely dependent parameters in JJ
         ixnoJ = ixnoJ + 1;
         indnoJ(ixnoJ,ind1) = (abs(ee1(:,ee0(j))) > 1.e-3)';
     end
-else  %rank(J)==length(theta) =>
-      %         disp('All parameters are identified at theta by the moments included in J')
 end
 
 % here there is no exact linear dependence, but there are several
@@ -109,27 +130,26 @@ jweak=zeros(1,npar);
 jweak_pair=zeros(npar,npar);
 
 if hess_flag==0,
-PcoJ = NaN(npar,npar);
+    PcoJ = NaN(npar,npar);
 
-for ii = 1:size(JJ1,2);
-    PcoJ(ind1(ii),ind1(ii)) = 1;
-    for jj = ii+1:size(JJ1,2);
-        PcoJ(ind1(ii),ind1(jj)) = cosn([JJ1(:,ii),JJ1(:,jj)]);
-        PcoJ(ind1(jj),ind1(ii)) = PcoJ(ind1(ii),ind1(jj));
+    for ii = 1:size(JJ1,2)
+        PcoJ(ind1(ii),ind1(ii)) = 1;
+        for jj = ii+1:size(JJ1,2)
+            PcoJ(ind1(ii),ind1(jj)) = cosn([JJ1(:,ii),JJ1(:,jj)]);
+            PcoJ(ind1(jj),ind1(ii)) = PcoJ(ind1(ii),ind1(jj));
+        end
     end
-end
 
-for j=1:npar,
-    if McoJ(j)>(1-1.e-10), 
-        jweak(j)=1;
-        [ipair, jpair] = find(PcoJ(j,j+1:end)>(1-1.e-10));
-        for jx=1:length(jpair),
-            jweak_pair(j, jpair(jx)+j)=1;
-            jweak_pair(jpair(jx)+j, j)=1;
+    for j=1:npar
+        if McoJ(j)>(1-1.e-10)
+            jweak(j)=1;
+            [ipair, jpair] = find(PcoJ(j,j+1:end)>(1-1.e-10));
+            for jx=1:length(jpair)
+                jweak_pair(j, jpair(jx)+j)=1;
+                jweak_pair(jpair(jx)+j, j)=1;
+            end
         end
     end
 end
-end
 
 jweak_pair=dyn_vech(jweak_pair)';
-
