@@ -1,38 +1,38 @@
-function  [LIK, lik, a, P] = missing_observations_kalman_filter(data_index,number_of_observations,no_more_missing_observations,Y,start,last,a,P,kalman_tol,riccati_tol,presample,T,Q,R,H,Z,mm,pp,rr,Zflag,diffuse_periods)
+function  [LIK, lik, a, P] = missing_observations_kalman_filter(data_index,number_of_observations,no_more_missing_observations,Y,start,last,a,P,kalman_tol,riccati_tol,rescale_prediction_error_covariance,presample,T,Q,R,H,Z,mm,pp,rr,Zflag,diffuse_periods)
 % Computes the likelihood of a state space model in the case with missing observations.
 %
 % INPUTS
 %    data_index                   [cell]      1*smpl cell of column vectors of indices.
 %    number_of_observations       [integer]   scalar.
 %    no_more_missing_observations [integer]   scalar.
-%    Y                            [double]    pp*smpl matrix of data.    
+%    Y                            [double]    pp*smpl matrix of data.
 %    start                        [integer]   scalar, index of the first observation.
 %    last                         [integer]   scalar, index of the last observation.
 %    a                            [double]    pp*1 vector, initial level of the state vector.
 %    P                            [double]    pp*pp matrix, covariance matrix of the initial state vector.
 %    kalman_tol                   [double]    scalar, tolerance parameter (rcond).
-%    riccati_tol                  [double]    scalar, tolerance parameter (riccati iteration).    
+%    riccati_tol                  [double]    scalar, tolerance parameter (riccati iteration).
 %    presample                    [integer]   scalar, presampling if strictly positive.
 %    T                            [double]    mm*mm transition matrix of the state equation.
-%    Q                            [double]    rr*rr covariance matrix of the structural innovations.    
+%    Q                            [double]    rr*rr covariance matrix of the structural innovations.
 %    R                            [double]    mm*rr matrix, mapping structural innovations to state variables.
-%    H                            [double]    pp*pp (or 1*1 =0 if no measurement error) covariance matrix of the measurement errors. 
-%    Z                            [integer]   pp*1 vector of indices for the observed variables.    
+%    H                            [double]    pp*pp (or 1*1 =0 if no measurement error) covariance matrix of the measurement errors.
+%    Z                            [integer]   pp*1 vector of indices for the observed variables.
 %    mm                           [integer]   scalar, dimension of the state vector.
 %    pp                           [integer]   scalar, number of observed variables.
-%    rr                           [integer]   scalar, number of structural innovations.    
-%    
-% OUTPUTS 
+%    rr                           [integer]   scalar, number of structural innovations.
+%
+% OUTPUTS
 %    LIK        [double]    scalar, MINUS loglikelihood
 %    lik        [double]    vector, density of observations in each period.
 %    a          [double]    mm*1 vector, estimated level of the states.
-%    P          [double]    mm*mm matrix, covariance matrix of the states.        
-%        
+%    P          [double]    mm*mm matrix, covariance matrix of the states.
+%
 %
 % NOTES
-%   The vector "lik" is used to evaluate the jacobian of the likelihood.   
+%   The vector "lik" is used to evaluate the jacobian of the likelihood.
 
-% Copyright (C) 2004-2012 Dynare Team
+% Copyright (C) 2004-2017 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -82,10 +82,10 @@ lik  = zeros(smpl,1);      % Initialization of the vector gathering the densitie
 LIK  = Inf;                % Default value of the log likelihood.
 oldK = Inf;
 notsteady   = 1;
-F_singular  = 1;
+F_singular  = true;
 s = 0;
 
-while notsteady & t<=last
+while notsteady && t<=last
     s  = t-start+1;
     d_index = data_index{t};
     if isempty(d_index)
@@ -102,18 +102,35 @@ while notsteady & t<=last
             v = Y(d_index,t) - a(z);
             F = P(z,z) + H(d_index,d_index);
         end
-        if rcond(F) < kalman_tol
-            if ~all(abs(F(:))<kalman_tol)
-                return
-            else
-                a = T*a;
-                P = T*P*transpose(T)+QQ;
+        badly_conditioned_F = false;
+        if rescale_prediction_error_covariance
+            sig=sqrt(diag(F));
+            if any(diag(F)<kalman_tol) || rcond(F./(sig*sig'))<kalman_tol
+                badly_conditioned_F = true;
             end
         else
-            F_singular = 0;
-            dF     = det(F);
-            iF     = inv(F);
-            lik(s) = log(dF) + transpose(v)*iF*v + length(d_index)*log(2*pi);
+            if rcond(F)<kalman_tol
+                badly_conditioned_F = true;
+            end
+        end
+        if badly_conditioned_F
+            if ~all(abs(F(:))<kalman_tol)
+                % Use univariate filter.
+                return
+            else
+                % Pathological case, discard draw
+                return
+            end
+        else
+            F_singular = false;
+            if rescale_prediction_error_covariance
+                log_dF = log(det(F./(sig*sig')))+2*sum(log(sig));
+                iF = inv(F./(sig*sig'))./(sig*sig');
+            else
+                log_dF = log(det(F));
+                iF = inv(F);
+            end
+            lik(s) = log_dF + transpose(v)*iF*v + length(d_index)*log(2*pi);
             if Zflag
                 K = P*z'*iF;
                 P = T*(P-K*z*P)*transpose(T)+QQ;
@@ -140,7 +157,7 @@ lik(1:s) = .5*lik(1:s);
 
 % Call steady state Kalman filter if needed.
 if t<=last
-    [tmp, lik(s+1:end)] = kalman_filter_ss(Y,t,last,a,T,K,iF,dF,Z,pp,Zflag);
+    [tmp, lik(s+1:end)] = kalman_filter_ss(Y, t, last, a, T, K, iF, log_dF, Z, pp, Zflag);
 end
 
 % Compute minus the log-likelihood.
