@@ -9,11 +9,11 @@ function dyn_save_graph(dirname,graph_name,graph_formats,TeX,names,texnames,capt
 %
 % OUTPUTS
 %   none
-%    
+%
 % SPECIAL REQUIREMENTS
 %    none
 %
-% Copyright (C) 2011 Dynare Team
+% Copyright (C) 2011-2017 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -30,40 +30,40 @@ function dyn_save_graph(dirname,graph_name,graph_formats,TeX,names,texnames,capt
 % You should have received a copy of the GNU General Public License
 % along with Dynare.  If not, see <http://www.gnu.org/licenses/>.
 
-    create_dir(dirname);
-    graph_name = [dirname filesep regexprep(graph_name,' ','_')];
-    if nargin <= 2
-        TeX = 0;
-    elseif nargin <= 4
-        names = {};
-        texnames = {};
-    elseif nargin <= 6
-        caption = '';
+create_dir(dirname);
+graph_name = [dirname filesep regexprep(graph_name,' ','_')];
+if nargin <= 2
+    TeX = 0;
+elseif nargin <= 4
+    names = {};
+    texnames = {};
+elseif nargin <= 6
+    caption = '';
+end
+
+if graph_formats.eps || TeX
+    print([ graph_name '.eps' ],'-depsc2');
+end
+if graph_formats.pdf && ~isoctave
+    print(graph_name,'-dpdf');
+end
+if graph_formats.fig && ~isoctave
+    print(graph_name,'-dfig');
+end
+
+if TeX
+    fh = fopen([graph_name '.tex'],'w');
+    for i=1:length(names)
+        fprintf(fh,'\\psfrag{%s}[1][][0.5][0]{%s}\n',names{i},texnames{i});
     end
-    
-    if graph_formats.eps || TeX
-        print([ graph_name '.eps' ],'-depsc2');
-    end
-    if graph_formats.pdf && ~isoctave
-        print(graph_name,'-dpdf');
-    end
-    if graph_formats.fig && ~isoctave
-        print(graph_name,'-dfig');
-    end
-    
-    if TeX
-        fh = fopen([graph_name '.tex'],'w');
-        for i=1:length(names)
-            fprintf(fh,'\\psfrag{%s}[1][][0.5][0]{%s}\n',names{i},texnames{i});
-        end
-        fprintf(fh,'\\centering \n');
-        fprintf(fh,'\\includegraphics[scale=0.5]{%s}\n',graph_name);
-        if caption
-            fprintf(fh,'\\caption{%s}',caption);
-        end
-        fprintf(fh,'\\label{Fig:%s}\n',graph_name);
-        fprintf(fh,'\\end{figure}\n');
-        fprintf(fh,'\n');
-        fprintf(fh,'%% End of TeX file.\n');
-        fclose(fh);
+    fprintf(fh,'\\centering \n');
+    fprintf(fh,'\\includegraphics[width=0.8\\textwidth]{%s}\n',graph_name);
+    if caption
+        fprintf(fh,'\\caption{%s}',caption);
     end
+    fprintf(fh,'\\label{Fig:%s}\n',graph_name);
+    fprintf(fh,'\\end{figure}\n');
+    fprintf(fh,'\n');
+    fprintf(fh,'%% End of TeX file.\n');
+    fclose(fh);
+end
