@@ -1,4 +1,4 @@
-function [loss,vx,info,exit_flag]=osr_obj(x,i_params,i_var,weights)
+function [loss,info,exit_flag,vx,junk]=osr_obj(x,i_params,i_var,weights)
 % objective function for optimal simple rules (OSR)
 % INPUTS
 %   x                         vector           values of the parameters
@@ -9,13 +9,15 @@ function [loss,vx,info,exit_flag]=osr_obj(x,i_params,i_var,weights)
 %
 % OUTPUTS
 %   loss                      scalar           loss function returned to solver
-%   vx                        vector           variances of the endogenous variables
 %   info                      vector           info vector returned by resol
 %   exit_flag                 scalar           exit flag returned to solver
+%   vx                        vector           variances of the endogenous variables
+%   junk                      empty            dummy output for conformable
+%                                              header
 %
 % SPECIAL REQUIREMENTS
 %   none
-% Copyright (C) 2005-2013 Dynare Team
+% Copyright (C) 2005-2017 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -38,7 +40,7 @@ global M_ oo_ options_ optimal_Q_ it_
 junk = [];
 exit_flag = 1;
 vx = [];
-info=0;
+info=zeros(4,1);
 loss=[];
 % set parameters of the policiy rule
 M_.params(i_params) = x;
@@ -47,43 +49,19 @@ M_.params(i_params) = x;
 it_ = M_.maximum_lag+1;
 [dr,info,M_,options_,oo_] = resol(0,M_,options_,oo_);
 
-switch info(1)
-  case 1
-    loss = 1e8;
-    return
-  case 2
-    loss = 1e8*min(1e3,info(2));
-    return
-  case 3
-    loss = 1e8*min(1e3,info(2));
-    return
-  case 4
-    loss = 1e8*min(1e3,info(2));
-    return
-  case 5
-    loss = 1e8;
-    return
-  case 6
-    loss = 1e8*min(1e3,info(2));
-    return
-  case 7
-    loss = 1e8*min(1e3);
-    return
-  case 8
-    loss = 1e8*min(1e3,info(2));
-    return
-  case 9
-    loss = 1e8*min(1e3,info(2));
-    return   
-  case 20
-    loss = 1e8*min(1e3,info(2));
-    return
-    otherwise
-  if info(1)~=0
-    loss = 1e8;
-    return;
-  end  
+if info(1)
+    if info(1) == 3 || info(1) == 4 || info(1) == 5 || info(1)==6 ||info(1) == 19 ||...
+                info(1) == 20 || info(1) == 21 || info(1) == 23 || info(1) == 26 || ...
+                info(1) == 81 || info(1) == 84 ||  info(1) == 85
+        loss = 1e8;
+        info(4)=info(2);
+        return
+    else
+        loss = 1e8;
+        info(4)=0.1;
+        return
+    end
 end
 
 vx = get_variance_of_endogenous_variables(dr,i_var);
-loss = weights(:)'*vx(:);
+loss = full(weights(:)'*vx(:));
