@@ -1,16 +1,16 @@
 function plot_icforecast(Variables,periods,options_)
 % Build plots for the conditional forecasts.
 %
-% INPUTS 
-%  o Variables     [char]        m*x array holding the names of the endogenous variables to be plotted. 
+% INPUTS
+%  o Variables     [char]        m*x array holding the names of the endogenous variables to be plotted.
 %
 % OUTPUTS
 %  None.
-% 
+%
 % SPECIAL REQUIREMENTS
 %  This routine has to be called after imcforecast.m.
 
-% Copyright (C) 2006-2013 Dynare Team
+% Copyright (C) 2006-2017 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -34,8 +34,16 @@ end
 
 load conditional_forecasts;
 
+eval(['forecast_periods = length(forecasts.cond.Mean.' Variables(1,:) ');']);
 if nargin==1 || isempty(periods) % Set default number of periods.
-    eval(['periods = length(forecasts.cond.Mean.' Variables(1,:) ');']);
+    periods=forecast_periods;
+else
+    periods=periods+1; %take care of initial period that is not forecasted
+end
+
+if periods>forecast_periods
+    fprintf('\nplot_icforecast:: Number of periods for plotting exceeds forecast horizon. Setting periods to %d.\n',forecast_periods-1)
+    periods=forecast_periods;
 end
 
 forecasts.graph.OutputDirectoryName = CheckPath('graphs',forecasts.graph.fname);
@@ -49,19 +57,15 @@ for i=1:size(Variables,1)
 end
 
 function build_figure(name,cci1,cci2,mm1,mm2,options_,graphoptions)
-hh = dyn_figure(options_,'Name',['Conditional forecast (' graphoptions.title ,'): ' name '.']);
+hh = dyn_figure(options_.nodisplay,'Name',['Conditional forecast (' graphoptions.title ,'): ' name '.']);
 H = length(mm1);
-h1 = area(1:H,cci1(2,1:H));
-set(h1,'BaseValue',min([min(cci1(1,:)),min(cci2(1,:))]))
-set(h1,'FaceColor',[.9 .9 .9])
+h1 = area(1:H,cci1(2,1:H),'BaseValue',min([min(cci1(1,:)),min(cci2(1,:))]),'FaceColor',[.9 .9 .9]);
 hold on
-h2 = area(1:H,cci1(1,1:H));
-set(h2,'BaseValue',min([min(cci1(1,:)),min(cci2(1,:))]))
-set(h2,'FaceColor',[1 1 1])
+h2 = area(1:H,cci1(1,1:H),'BaseValue',min([min(cci1(1,:)),min(cci2(1,:))]),'FaceColor',[1 1 1]);
 plot(1:H,mm1,'-k','linewidth',3)
 plot(1:H,mm2,'--k','linewidth',3)
 plot(1:H,cci2(1,:),'--k','linewidth',1)
 plot(1:H,cci2(2,:),'--k','linewidth',1)
 axis tight
 hold off
-dyn_saveas(hh,[graphoptions.OutputDirectoryName '/Conditional_forecast_',strrep(deblank(graphoptions.title),' ','_'),'_',deblank(name)],options_)
\ No newline at end of file
+dyn_saveas(hh,[graphoptions.OutputDirectoryName '/Conditional_forecast_',strrep(deblank(graphoptions.title),' ','_'),'_',deblank(name)],options_.nodisplay,options_.graph_format)
\ No newline at end of file
