@@ -1,6 +1,6 @@
 function info = ramsey_policy(var_list)
 
-% Copyright (C) 2007-2012 Dynare Team
+% Copyright (C) 2007-2017 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -22,6 +22,23 @@ global options_ oo_ M_
 options_.ramsey_policy = 1;
 oldoptions = options_;
 options_.order = 1;
+
+%test whether specification matches
+inst_nbr = size(options_.instruments,1);
+if inst_nbr~=0
+    orig_endo_aux_nbr = M_.orig_endo_nbr + min(find([M_.aux_vars.type] == 6)) - 1;
+    implied_inst_nbr = orig_endo_aux_nbr - M_.orig_eq_nbr;
+    if inst_nbr>implied_inst_nbr
+        error('You have specified more instruments than there are omitted equations')
+    elseif inst_nbr<implied_inst_nbr
+        error('You have specified fewer instruments than there are omitted equations')
+    end
+else
+    if options_.steadystate_flag
+        error('You have specified a steady state file, but not provided an instrument. Either delete the steady state file or provide an instrument')
+    end
+end
+
 info = stoch_simul(var_list);
 
 oo_.steady_state = oo_.dr.ys;
