@@ -2,17 +2,17 @@ function z = resid(junk)
 % function z = resid(junk)
 %
 % Computes static residuals associated with the guess values.
-% 
+%
 % INPUTS
 %    junk:   dummy value for backward compatibility
-%    
+%
 % OUTPUTS
 %    z:      residuals
-%        
+%
 % SPECIAL REQUIREMENTS
 %    none
 
-% Copyright (C) 2001-2012 Dynare Team
+% Copyright (C) 2001-2017 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -51,6 +51,16 @@ Sigma_e = M_.Sigma_e;
 M_.Sigma_e = zeros(size(Sigma_e));
 
 info = 0;
+if any(imag(oo_.steady_state))
+    imagrow=find(imag(oo_.steady_state));
+    if ~isempty(imagrow)
+        fprintf('\nresid: The initial values for the steady state of the following variables are complex:\n');
+        for iter=1:length(imagrow)
+            fprintf('%s\n',M_.endo_names(imagrow(iter),:));
+        end
+    end
+end
+
 if options_.steadystate_flag
     [oo_.steady_state,M_.params,info] = ...
         evaluate_steady_state(oo_.steady_state,M_,options_,oo_,0);
@@ -108,9 +118,4 @@ if nargout == 0
     skipline(2)
 end
 
-if info(1)
-    print_info(info,options_.noprint, options_)
-end
-
-
 oo_.steady_state = steady_state_old;
