@@ -4,21 +4,21 @@ function [xparam1, estim_params_, bayestopt_, lb, ub, M_]=set_prior(estim_params
 %
 % INPUTS
 %    o estim_params_    [structure] characterizing parameters to be estimated.
-%    o M_               [structure] characterizing the model. 
-%    o options_         [structure] 
-%    
+%    o M_               [structure] characterizing the model.
+%    o options_         [structure]
+%
 % OUTPUTS
 %    o xparam1          [double]    vector of parameters to be estimated (initial values)
 %    o estim_params_    [structure] characterizing parameters to be estimated
 %    o bayestopt_       [structure] characterizing priors
-%    o lb               [double]    vector of lower bounds for the estimated parameters. 
+%    o lb               [double]    vector of lower bounds for the estimated parameters.
 %    o ub               [double]    vector of upper bounds for the estimated parameters.
 %    o M_               [structure] characterizing the model.
-%    
+%
 % SPECIAL REQUIREMENTS
 %    None
 
-% Copyright (C) 2003-2013 Dynare Team
+% Copyright (C) 2003-2017 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -48,55 +48,55 @@ estim_params_.ncn = ncn; % correlation between endogenous variables, i.e. measur
 estim_params_.np = np;   % other parameters of the model
 
 xparam1 = [];
-ub = [];
-lb = [];
+ub = []; % Upper bound imposed for optimization.
+lb = []; % Lower bound imposed for optimization.
 bayestopt_.pshape = [];
 bayestopt_.p1 = []; % prior mean
 bayestopt_.p2 = []; % prior standard deviation
-bayestopt_.p3 = []; % lower bound
-bayestopt_.p4 = []; % upper bound
+bayestopt_.p3 = []; % lower bound of the distribution, only considering whether a generalized distribution is used, not when the prior is truncated
+bayestopt_.p4 = []; % upper bound of the distribution, only considering whether a generalized distribution is used, not when the prior is truncated
 bayestopt_.p5 = zeros(nvx+nvn+ncx+ncn+np,1); % prior mode
 bayestopt_.p6 = []; % first hyper-parameter (\alpha for the BETA and GAMMA distributions, s for the INVERSE GAMMAs, expectation for the GAUSSIAN distribution, lower bound for the UNIFORM distribution).
 bayestopt_.p7 = []; % second hyper-parameter (\beta for the BETA and GAMMA distributions, \nu for the INVERSE GAMMAs, standard deviation for the GAUSSIAN distribution, upper bound for the UNIFORM distribution).
 
-bayestopt_.jscale = [];
+bayestopt_.jscale = []; %jscale might subsequently be overwritten by mode_compute=6 or check_posterior_sampler_options
 bayestopt_.name = {};
 if nvx
     xparam1 = estim_params_.var_exo(:,2);
-    ub = estim_params_.var_exo(:,4); 
-    lb = estim_params_.var_exo(:,3); 
+    ub = estim_params_.var_exo(:,4);
+    lb = estim_params_.var_exo(:,3);
     bayestopt_.pshape =  estim_params_.var_exo(:,5);
     bayestopt_.p1 =  estim_params_.var_exo(:,6);
     bayestopt_.p2 =  estim_params_.var_exo(:,7);
-    bayestopt_.p3 =  estim_params_.var_exo(:,8);
-    bayestopt_.p4 =  estim_params_.var_exo(:,9);
+    bayestopt_.p3 =  estim_params_.var_exo(:,8); %take generalized distribution into account
+    bayestopt_.p4 =  estim_params_.var_exo(:,9); %take generalized distribution into account
     bayestopt_.jscale =  estim_params_.var_exo(:,10);
     bayestopt_.name = cellstr(M_.exo_names(estim_params_.var_exo(:,1),:));
 end
 if nvn
     estim_params_.nvn_observable_correspondence=NaN(nvn,1); % stores number of corresponding observable
     if isequal(M_.H,0) %if no previously set measurement error, initialize H
-        nvarobs = size(options_.varobs,1);
+        nvarobs = length(options_.varobs);
         M_.H = zeros(nvarobs,nvarobs);
         M_.Correlation_matrix_ME = eye(nvarobs);
     end
     for i=1:nvn
-        obsi_ = strmatch(deblank(M_.endo_names(estim_params_.var_endo(i,1),:)),deblank(options_.varobs),'exact');
+        obsi_ = strmatch(deblank(M_.endo_names(estim_params_.var_endo(i,1),:)),options_.varobs,'exact');
         if isempty(obsi_)
             error(['The variable ' deblank(M_.endo_names(estim_params_.var_endo(i,1),:)) ' has to be declared as observable since you assume a measurement error on it.'])
         end
         estim_params_.nvn_observable_correspondence(i,1)=obsi_;
     end
     xparam1 = [xparam1; estim_params_.var_endo(:,2)];
-    ub = [ub; estim_params_.var_endo(:,4)]; 
-    lb = [lb; estim_params_.var_endo(:,3)]; 
+    ub = [ub; estim_params_.var_endo(:,4)];
+    lb = [lb; estim_params_.var_endo(:,3)];
     bayestopt_.pshape = [ bayestopt_.pshape; estim_params_.var_endo(:,5)];
     bayestopt_.p1 = [ bayestopt_.p1; estim_params_.var_endo(:,6)];
     bayestopt_.p2 = [ bayestopt_.p2; estim_params_.var_endo(:,7)];
-    bayestopt_.p3 = [ bayestopt_.p3; estim_params_.var_endo(:,8)];
-    bayestopt_.p4 = [ bayestopt_.p4; estim_params_.var_endo(:,9)];
+    bayestopt_.p3 = [ bayestopt_.p3; estim_params_.var_endo(:,8)]; %take generalized distribution into account
+    bayestopt_.p4 = [ bayestopt_.p4; estim_params_.var_endo(:,9)]; %take generalized distribution into account
     bayestopt_.jscale = [ bayestopt_.jscale; estim_params_.var_endo(:,10)];
-    bayestopt_.name = [ bayestopt_.name; cellstr(options_.varobs(estim_params_.nvn_observable_correspondence,:))];
+    bayestopt_.name = [ bayestopt_.name; transpose(options_.varobs(estim_params_.nvn_observable_correspondence))];
 end
 if ncx
     xparam1 = [xparam1; estim_params_.corrx(:,3)];
@@ -105,8 +105,8 @@ if ncx
     bayestopt_.pshape = [ bayestopt_.pshape; estim_params_.corrx(:,6)];
     bayestopt_.p1 = [ bayestopt_.p1; estim_params_.corrx(:,7)];
     bayestopt_.p2 = [ bayestopt_.p2; estim_params_.corrx(:,8)];
-    bayestopt_.p3 = [ bayestopt_.p3; estim_params_.corrx(:,9)];
-    bayestopt_.p4 = [ bayestopt_.p4; estim_params_.corrx(:,10)];
+    bayestopt_.p3 = [ bayestopt_.p3; estim_params_.corrx(:,9)]; %take generalized distribution into account
+    bayestopt_.p4 = [ bayestopt_.p4; estim_params_.corrx(:,10)]; %take generalized distribution into account
     bayestopt_.jscale = [ bayestopt_.jscale; estim_params_.corrx(:,11)];
     bayestopt_.name = [bayestopt_.name; cellstr([repmat('corr ',ncx,1)...
                         deblank(M_.exo_names(estim_params_.corrx(:,1),:)) ...
@@ -115,7 +115,7 @@ end
 if ncn
     estim_params_.corrn_observable_correspondence=NaN(ncn,2);
     if isequal(M_.H,0)
-        nvarobs = size(options_.varobs,1);
+        nvarobs = length(options_.varobs);
         M_.H = zeros(nvarobs,nvarobs);
         M_.Correlation_matrix_ME = eye(nvarobs);
     end
@@ -125,8 +125,8 @@ if ncn
     bayestopt_.pshape = [ bayestopt_.pshape; estim_params_.corrn(:,6)];
     bayestopt_.p1 = [ bayestopt_.p1; estim_params_.corrn(:,7)];
     bayestopt_.p2 = [ bayestopt_.p2; estim_params_.corrn(:,8)];
-    bayestopt_.p3 = [ bayestopt_.p3; estim_params_.corrn(:,9)];
-    bayestopt_.p4 = [ bayestopt_.p4; estim_params_.corrn(:,10)];
+    bayestopt_.p3 = [ bayestopt_.p3; estim_params_.corrn(:,9)]; %take generalized distribution into account
+    bayestopt_.p4 = [ bayestopt_.p4; estim_params_.corrn(:,10)]; %take generalized distribution into account
     bayestopt_.jscale = [ bayestopt_.jscale; estim_params_.corrn(:,11)];
     bayestopt_.name = [bayestopt_.name; cellstr([repmat('corr ',ncn,1) ...
                         deblank(M_.endo_names(estim_params_.corrn(:,1),:)) ...
@@ -134,8 +134,8 @@ if ncn
     for i=1:ncn
         k1 = estim_params_.corrn(i,1);
         k2 = estim_params_.corrn(i,2);
-        obsi1 = strmatch(deblank(M_.endo_names(k1,:)),deblank(options_.varobs),'exact'); %find correspondence to varobs to construct H in set_all_paramters
-        obsi2 = strmatch(deblank(M_.endo_names(k2,:)),deblank(options_.varobs),'exact');
+        obsi1 = strmatch(deblank(M_.endo_names(k1,:)),options_.varobs,'exact'); %find correspondence to varobs to construct H in set_all_paramters
+        obsi2 = strmatch(deblank(M_.endo_names(k2,:)),options_.varobs,'exact');
         estim_params_.corrn_observable_correspondence(i,:)=[obsi1,obsi2]; %save correspondence
     end
 end
@@ -146,18 +146,21 @@ if np
     bayestopt_.pshape = [ bayestopt_.pshape; estim_params_.param_vals(:,5)];
     bayestopt_.p1 = [ bayestopt_.p1; estim_params_.param_vals(:,6)];
     bayestopt_.p2 = [ bayestopt_.p2; estim_params_.param_vals(:,7)];
-    bayestopt_.p3 = [ bayestopt_.p3; estim_params_.param_vals(:,8)];
-    bayestopt_.p4 = [ bayestopt_.p4; estim_params_.param_vals(:,9)];
+    bayestopt_.p3 = [ bayestopt_.p3; estim_params_.param_vals(:,8)]; %take generalized distribution into account
+    bayestopt_.p4 = [ bayestopt_.p4; estim_params_.param_vals(:,9)]; %take generalized distribution into account
     bayestopt_.jscale = [ bayestopt_.jscale; estim_params_.param_vals(:,10)];
     bayestopt_.name = [bayestopt_.name; cellstr(M_.param_names(estim_params_.param_vals(:,1),:))];
 end
 
-bayestopt_.ub = ub;
-bayestopt_.lb = lb;
-
 bayestopt_.p6 = NaN(size(bayestopt_.p1)) ;
 bayestopt_.p7 = bayestopt_.p6 ;
 
+%% check for point priors and disallow them as they do not work with MCMC
+if any(bayestopt_.p2 ==0)
+    error(sprintf(['Error in prior for %s: you cannot use a point prior in estimation. Either increase the prior standard deviation',...
+                   ' or fix the parameter completely.'], bayestopt_.name{bayestopt_.p2 ==0}))
+end
+
 % generalized location parameters by default for beta distribution
 k = find(bayestopt_.pshape == 1);
 k1 = find(isnan(bayestopt_.p3(k)));
@@ -165,24 +168,16 @@ bayestopt_.p3(k(k1)) = zeros(length(k1),1);
 k1 = find(isnan(bayestopt_.p4(k)));
 bayestopt_.p4(k(k1)) = ones(length(k1),1);
 for i=1:length(k)
-    if (bayestopt_.p1(k(i))<bayestopt_.p3(k(i))) || (bayestopt_.p1(k(i))>bayestopt_.p4(k(i)))
-        error(['The prior mean of ' bayestopt_.name{k(i)} ' has to be between the lower (' num2str(bayestopt_.p3(k(i))) ') and upper (' num2str(bayestopt_.p4(k(i))) ') bounds of the beta prior density!']);
+    [bayestopt_.p6(k(i)), bayestopt_.p7(k(i))] = beta_specification(bayestopt_.p1(k(i)), bayestopt_.p2(k(i))^2, bayestopt_.p3(k(i)), bayestopt_.p4(k(i)), bayestopt_.name{k(i)});
+    if bayestopt_.p6(k(i))<1 || bayestopt_.p7(k(i))<1
+        fprintf('Prior distribution for parameter %s has unbounded density!\n',bayestopt_.name{k(i)})
     end
-    mu = (bayestopt_.p1(k(i))-bayestopt_.p3(k(i)))/(bayestopt_.p4(k(i))-bayestopt_.p3(k(i)));
-    stdd = bayestopt_.p2(k(i))/(bayestopt_.p4(k(i))-bayestopt_.p3(k(i)));
-    if stdd^2 > (1-mu)*mu
-        error(sprintf(['Error in prior for %s: in a beta distribution with ' ...
-                       'mean %f, the standard error can''t be larger than' ...
-                       ' %f.'], bayestopt_.name{k(i)},mu,sqrt((1-mu)*mu)))
-    end
-    bayestopt_.p6(k(i)) = (1-mu)*mu^2/stdd^2 - mu ;
-    bayestopt_.p7(k(i)) = bayestopt_.p6(k(i))*(1/mu-1) ;
     m = compute_prior_mode([ bayestopt_.p6(k(i)) , bayestopt_.p7(k(i)) , bayestopt_.p3(k(i)) , bayestopt_.p4(k(i)) ],1);
     if length(m)==1
         bayestopt_.p5(k(i)) = m;
     else
         disp(['Prior distribution for parameter ' bayestopt_.name{k(i)}  ' has two modes!'])
-        bayestopt_.p5(k(i)) = bayestopt_.p1(k(i)) ; 
+        bayestopt_.p5(k(i)) = m(1);
     end
 end
 
@@ -193,26 +188,22 @@ k2 = find(isnan(bayestopt_.p4(k)));
 bayestopt_.p3(k(k1)) = zeros(length(k1),1);
 bayestopt_.p4(k(k2)) = Inf(length(k2),1);
 for i=1:length(k)
-    if isinf(bayestopt_.p2(k(i)))
-        error(['Infinite prior standard deviation for parameter ' bayestopt_.name{k(i)}  ' is not allowed (Gamma prior)!'])
+    [bayestopt_.p6(k(i)), bayestopt_.p7(k(i))] = gamma_specification(bayestopt_.p1(k(i)), bayestopt_.p2(k(i))^2, bayestopt_.p3(k(i)), bayestopt_.name{k(i)});
+    if bayestopt_.p6(k(i))<1
+        fprintf('Prior distribution for parameter %s has unbounded density!\n',bayestopt_.name{k(i)})
     end
-    mu = bayestopt_.p1(k(i))-bayestopt_.p3(k(i));
-    bayestopt_.p7(k(i)) = bayestopt_.p2(k(i))^2/mu ;
-    bayestopt_.p6(k(i)) = mu/bayestopt_.p7(k(i)) ;  
     bayestopt_.p5(k(i)) = compute_prior_mode([ bayestopt_.p6(k(i)) , bayestopt_.p7(k(i)) , bayestopt_.p3(k(i)) ], 2) ;
 end
 
 % truncation parameters by default for normal distribution
 k  = find(bayestopt_.pshape == 3);
 k1 = find(isnan(bayestopt_.p3(k)));
+k2 = find(isnan(bayestopt_.p4(k)));
 bayestopt_.p3(k(k1)) = -Inf*ones(length(k1),1);
-k1 = find(isnan(bayestopt_.p4(k)));
-bayestopt_.p4(k(k1)) = Inf*ones(length(k1),1);
-for i=1:length(k)
-    bayestopt_.p6(k(i)) = bayestopt_.p1(k(i)) ; 
-    bayestopt_.p7(k(i)) = bayestopt_.p2(k(i)) ;
-    bayestopt_.p5(k(i)) = bayestopt_.p1(k(i)) ;
-end
+bayestopt_.p4(k(k2)) = Inf*ones(length(k2),1);
+bayestopt_.p6(k) = bayestopt_.p1(k);
+bayestopt_.p7(k) = bayestopt_.p2(k);
+bayestopt_.p5(k) = bayestopt_.p1(k);
 
 % inverse gamma distribution (type 1)
 k = find(bayestopt_.pshape == 4);
@@ -221,10 +212,9 @@ k2 = find(isnan(bayestopt_.p4(k)));
 bayestopt_.p3(k(k1)) = zeros(length(k1),1);
 bayestopt_.p4(k(k2)) = Inf(length(k2),1);
 for i=1:length(k)
-    [bayestopt_.p6(k(i)),bayestopt_.p7(k(i))] = ...
-        inverse_gamma_specification(bayestopt_.p1(k(i))-bayestopt_.p3(k(i)),bayestopt_.p2(k(i)),1,0) ;
-    bayestopt_.p5(k(i)) = compute_prior_mode([ bayestopt_.p6(k(i)) , bayestopt_.p7(k(i)) , bayestopt_.p3(k(i)) ], 4) ;
-end  
+    [bayestopt_.p6(k(i)),bayestopt_.p7(k(i))] = inverse_gamma_specification(bayestopt_.p1(k(i)), bayestopt_.p2(k(i))^2, bayestopt_.p3(k(i)), 1, false, bayestopt_.name{k(i)});
+    bayestopt_.p5(k(i)) = compute_prior_mode([ bayestopt_.p6(k(i)) , bayestopt_.p7(k(i)) , bayestopt_.p3(k(i)) ], 4);
+end
 
 % uniform distribution
 k = find(bayestopt_.pshape == 5);
@@ -244,10 +234,21 @@ bayestopt_.p3(k(k1)) = zeros(length(k1),1);
 bayestopt_.p4(k(k2)) = Inf(length(k2),1);
 for i=1:length(k)
     [bayestopt_.p6(k(i)),bayestopt_.p7(k(i))] = ...
-        inverse_gamma_specification(bayestopt_.p1(k(i))-bayestopt_.p3(k(i)),bayestopt_.p2(k(i)),2,0);
+        inverse_gamma_specification(bayestopt_.p1(k(i)), bayestopt_.p2(k(i))^2, bayestopt_.p3(k(i)), 2, false, bayestopt_.name{k(i)});
     bayestopt_.p5(k(i)) = compute_prior_mode([ bayestopt_.p6(k(i)) , bayestopt_.p7(k(i)) , bayestopt_.p3(k(i)) ], 6) ;
 end
 
+% Weibull distribution
+k = find(bayestopt_.pshape == 8);
+k1 = find(isnan(bayestopt_.p3(k)));
+k2 = find(isnan(bayestopt_.p4(k)));
+bayestopt_.p3(k(k1)) = zeros(length(k1),1);
+bayestopt_.p4(k(k2)) = Inf(length(k2),1);
+for i=1:length(k)
+    [bayestopt_.p6(k(i)),bayestopt_.p7(k(i))] = weibull_specification(bayestopt_.p1(k(i)), bayestopt_.p2(k(i))^2, bayestopt_.p3(k(i)), bayestopt_.name{k(i)});
+    bayestopt_.p5(k(i)) = compute_prior_mode([ bayestopt_.p6(k(i)) , bayestopt_.p7(k(i)) , bayestopt_.p3(k(i)) ], 8) ;
+end
+
 k = find(isnan(xparam1));
 if ~isempty(k)
     xparam1(k) = bayestopt_.p1(k);
@@ -259,8 +260,9 @@ if options_.initialize_estimated_parameters_with_the_prior_mode
     if ~isempty(k)
         xparam1(k) = bayestopt_.p1(k);
     end
-    xparam1 = transpose(xparam1);
-end 
+end
+
+
 
 % I create subfolder M_.dname/prior if needed.
 CheckPath('prior',M_.dname);
@@ -298,7 +300,4 @@ end
 
 % initialize persistent variables in priordens()
 priordens(xparam1,bayestopt_.pshape,bayestopt_.p6,bayestopt_.p7, ...
-          bayestopt_.p3,bayestopt_.p4,1);
-
-% Put bayestopt_ in matlab's workspace
-assignin('base','bayestopt_',bayestopt_);
\ No newline at end of file
+          bayestopt_.p3,bayestopt_.p4,1);
\ No newline at end of file
