@@ -1,24 +1,29 @@
-function oo_ = shock_decomposition(M_,oo_,options_,varlist)
+function [oo_,M_] = shock_decomposition(M_,oo_,options_,varlist,bayestopt_,estim_params_)
 % function z = shock_decomposition(M_,oo_,options_,varlist)
 % Computes shocks contribution to a simulated trajectory. The field set is
 % oo_.shock_decomposition. It is a n_var by nshock+2 by nperiods array. The
 % first nshock columns store the respective shock contributions, column n+1
 % stores the role of the initial conditions, while column n+2 stores the
-% value of the smoothed variables.
+% value of the smoothed variables.  Both the variables and shocks are stored
+% in the order of declaration, i.e. M_.endo_names and M_.exo_names, respectively.
 %
 % INPUTS
 %    M_:          [structure]  Definition of the model
 %    oo_:         [structure]  Storage of results
 %    options_:    [structure]  Options
 %    varlist:     [char]       List of variables
+%    bayestopt_:  [structure]  describing the priors
+%    estim_params_: [structure] characterizing parameters to be estimated
 %
 % OUTPUTS
 %    oo_:         [structure]  Storage of results
+%    M_:          [structure]  Definition of the model; makes sure that
+%                               M_.params is correctly updated
 %
 % SPECIAL REQUIREMENTS
 %    none
 
-% Copyright (C) 2009-2013 Dynare Team
+% Copyright (C) 2009-2017 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -40,7 +45,8 @@ if size(varlist,1) == 0
     varlist = M_.endo_names(1:M_.orig_endo_nbr,:);
 end
 
-[i_var,nvar] = varlist_indices(varlist,M_.endo_names);
+[i_var,nvar,index_uniques] = varlist_indices(varlist,M_.endo_names);
+varlist=varlist(index_uniques,:);
 
 % number of variables
 endo_nbr = M_.endo_nbr;
@@ -53,7 +59,9 @@ parameter_set = options_.parameter_set;
 if isempty(parameter_set)
     if isfield(oo_,'posterior_mean')
         parameter_set = 'posterior_mean';
-    elseif isfield(oo_,'posterior_mode')
+    elseif isfield(oo_,'mle_mode')
+        parameter_set = 'mle_mode';
+    elseif isfield(oo_,'posterior')
         parameter_set = 'posterior_mode';
     else
         error(['shock_decomposition: option parameter_set is not specified ' ...
@@ -61,10 +69,13 @@ if isempty(parameter_set)
     end
 end
 
-oo = evaluate_smoother(parameter_set,varlist);
+
+options_.selected_variables_only = 0; %make sure all variables are stored
+options_.plot_priors=0;
+[oo_, M_, junk1, junk2, Smoothed_Variables_deviation_from_mean] = evaluate_smoother(parameter_set, varlist, M_, oo_, options_, bayestopt_, estim_params_);
 
 % reduced form
-dr = oo.dr;
+dr = oo_.dr;
 
 % data reordering
 order_var = dr.order_var;
@@ -76,18 +87,17 @@ A = dr.ghx;
 B = dr.ghu;
 
 % initialization
+gend = size(oo_.SmoothedShocks.(deblank(M_.exo_names(1,:))),1);
+epsilon=NaN(nshocks,gend);
 for i=1:nshocks
-    epsilon(i,:) = eval(['oo.SmoothedShocks.' M_.exo_names(i,:)]);
+    epsilon(i,:) = oo_.SmoothedShocks.(deblank(M_.exo_names(i,:)));
 end
-gend = size(epsilon,2);
 
 z = zeros(endo_nbr,nshocks+2,gend);
-for i=1:endo_nbr
-    z(i,end,:) = eval(['oo.SmoothedVariables.' M_.endo_names(i,:)]);
-end
+
+z(:,end,:) = Smoothed_Variables_deviation_from_mean;
 
 maximum_lag = M_.maximum_lag;
-lead_lag_incidence = M_.lead_lag_incidence;
 
 k2 = dr.kstate(find(dr.kstate(:,2) <= maximum_lag+1),[1 2]);
 i_state = order_var(k2(:,1))+(min(i,maximum_lag)+1-k2(:,2))*M_.endo_nbr;
@@ -95,7 +105,7 @@ for i=1:gend
     if i > 1 && i <= maximum_lag+1
         lags = min(i-1,maximum_lag):-1:1;
     end
-    
+
     if i > 1
         tempx = permute(z(:,1:nshocks,lags),[1 3 2]);
         m = min(i-1,maximum_lag);
@@ -104,11 +114,14 @@ for i=1:gend
         lags = lags+1;
     end
 
-    z(:,1:nshocks,i) = z(:,1:nshocks,i) + B(inv_order_var,:).*repmat(epsilon(:,i)',endo_nbr,1);
+    if i > options_.shock_decomp.init_state
+        z(:,1:nshocks,i) = z(:,1:nshocks,i) + B(inv_order_var,:).*repmat(epsilon(:,i)',endo_nbr,1);
+    end
     z(:,nshocks+1,i) = z(:,nshocks+2,i) - sum(z(:,1:nshocks,i),2);
 end
 
-
 oo_.shock_decomposition = z;
 
-graph_decomp(z,M_.exo_names,M_.endo_names,i_var,options_.initial_date,M_,options_)
+if ~options_.no_graph.shock_decomposition
+    plot_shock_decomposition(M_,oo_,options_,varlist);
+end
\ No newline at end of file
