@@ -2,19 +2,19 @@ function [param,sigma] = simulated_moments_estimation(dataset,options,parallel)
 % Performs estimation by Simulated Moments Method.
 %
 % INPUTS:
-%  xparam          [double]  p*1 vector of initial values for the estimated parameters. 
+%  xparam          [double]  p*1 vector of initial values for the estimated parameters.
 %  dataset         [      ]  Structure describing the data set.
 %  options         [      ]  Structure defining options for SMM.
-%  parallel        [      ]  Structure defining the parallel mode settings (optional). 
+%  parallel        [      ]  Structure defining the parallel mode settings (optional).
 %
-% OUTPUTS: 
+% OUTPUTS:
 %  param           [double]  p*1 vector of point estimates for the parameters.
 %  sigma           [double]  p*p covariance matrix of the SMM estimates.
 %
 % SPECIAL REQUIREMENTS
 %  The user has to provide a file where the moment conditions are defined.
 
-% Copyright (C) 2010-2012 Dynare Team
+% Copyright (C) 2010-2017 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -87,7 +87,7 @@ options.estimated_parameters.upper_bound = [options.estimated_parameters.upper_b
 
 options.number_of_simulated_sample = 0;
 for i=1:length(parallel)
-    options.number_of_simulated_sample = options.number_of_simulated_sample + parallel(i).number_of_jobs*parallel(i).number_of_simulations; 
+    options.number_of_simulated_sample = options.number_of_simulated_sample + parallel(i).number_of_jobs*parallel(i).number_of_simulations;
 end
 
 options.observed_variables_idx = dataset.observed_variables_idx;
@@ -97,7 +97,7 @@ if nargin>2
     if ~isunix
         error('The parallel version of SMM estimation is not implemented for non unix platforms!')
     end
-    [junk,hostname] = unix('hostname --fqdn');    
+    [junk,hostname] = unix('hostname --fqdn');
     hostname = deblank(hostname);
     master_is_running_a_job = 0;
     for i=1:length(parallel)
@@ -204,7 +204,7 @@ end
 skipline()
 
 if options.optimization_routine==1
-    % Set options for csminwel. 
+    % Set options for csminwel.
     H0 = 1e-4*eye(options.estimated_parameters.nb);
     ct = 1e-4;
     it = 1000;
@@ -212,7 +212,7 @@ if options.optimization_routine==1
     % Minimization of the objective function.
     if nargin==2
         [fval,param,grad,hessian_csminwel,itct,fcount,retcodehat] = ...
-            csminwel1('smm_objective',xparam,H0,[],ct,it,2,options_.gradient_epsilon,sample_moments,weighting_matrix,options);    
+            csminwel1('smm_objective',xparam,H0,[],ct,it,2,options_.gradient_epsilon,sample_moments,weighting_matrix,options);
     elseif nargin>2
         [fval,param,grad,hessian_csminwel,itct,fcount,retcodehat] = ...
             csminwel1('smm_objective',xparam,H0,[],ct,it,2,options_.gradient_epsilon,sample_moments,weighting_matrix,options,parallel);
@@ -236,7 +236,7 @@ elseif options.optimization_routine==0% Compute the variance of the SMM estimato
     V = (1+1/options.number_of_simulated_sample)*G'*long_run_covariance*G;
     [param,diag(V)]
 elseif options.optimization_routine<0
-    T = -options.optimization_routine;% length of the simulated time series.            
+    T = -options.optimization_routine;% length of the simulated time series.
     time_series = extended_path(oo_.steady_state,T,1);
     save time_series.mat;
 end
@@ -248,7 +248,7 @@ fid = fopen(['job' int2str(slave_number) '.m'],'w');
 
 fprintf(fid,['% Generated by ' hostname '.\n\n']);
 
-if ( strcmpi(hostname,remotename) && (job_number>1) )  || ~strcmpi(hostname,remotename) 
+if ( strcmpi(hostname,remotename) && (job_number>1) )  || ~strcmpi(hostname,remotename)
     fprintf(fid,'load(''master_variables'');\n');
     fprintf(fid,'assignin(''base'',''M_'',M_);\n');
     fprintf(fid,'assignin(''base'',''oo_'',oo_);\n');
@@ -270,9 +270,9 @@ fprintf(fid,'M_.Sigma_e = diag(tmp);')
 
 fprintf(fid,['stream=RandStream(''mt19937ar'',''Seed'',' int2str(slave_number) ');\n']);
 if matlab_ver_less_than('7.12')
-      fprintf(fid,['RandStream.setDefaultStream(stream);\n\n']);
+    fprintf(fid,['RandStream.setDefaultStream(stream);\n\n']);
 else
-      fprintf(fid,['RandStream.setGlobalStream(stream);\n\n']);
+    fprintf(fid,['RandStream.setGlobalStream(stream);\n\n']);
 end
 
 fprintf(fid,['maxNumCompThreads(' int2str(threads_per_job) ');\n\n']);
@@ -282,7 +282,7 @@ fprintf(fid,['    time_series = extended_path([],' int2str(sample_size) ',1);\n'
 fprintf(fid,['    data = time_series([' int2str(observed_variables_idx) '],' int2str(burn_in_periods) '+1:' int2str(sample_size) ');\n']);
 fprintf(fid,['    eval(''tmp = ' moments_file_name '(data);'');\n']);
 fprintf(fid,['    simulated_moments = simulated_moments + tmp;\n']);
-fprintf(fid,['end;\n\n']);
+fprintf(fid,['end\n\n']);
 
 fprintf(fid,['simulated_moments = simulated_moments/' int2str(number_of_simulations) ';\n']);
 fprintf(fid,['save(''simulated_moments_slave_' int2str(slave_number) '.dat'',''simulated_moments'',''-ascii'');\n']);
@@ -295,7 +295,7 @@ else
     fprintf(fid,['unix(''rm simulated_moments_slave_' int2str(slave_number) '.dat'');\n']);
 end
 
-if ((job_number>1) && strcmpi(hostname,remotename)) || ~strcmpi(hostname,remotename) 
+if ((job_number>1) && strcmpi(hostname,remotename)) || ~strcmpi(hostname,remotename)
     fprintf(fid,'exit');
 end
 
