@@ -1,23 +1,24 @@
 function trace_plot(options_,M_,estim_params_,type,blck,name1,name2)
-% This function build trace plot for the metropolis hastings draws.
-% 
+% This function builds trace plot for the Metropolis-Hastings draws.
 %
-% INPUTS 
+% INPUTS
 %
 %   options_        [structure]    Dynare structure.
 %   M_              [structure]    Dynare structure (related to model definition).
 %   estim_params_   [structure]    Dynare structure (related to estimation).
-%   type            [string]       'DeepParameter', 'MeasurementError' (for measurement equation error) or 'StructuralShock' (for structural shock).
+%   type            [string]       'DeepParameter', 'MeasurementError' (for measurement equation error),
+%                                  'StructuralShock' (for structural shock)
+%                                  or 'PosteriorDensity (for posterior density)'
 %   blck            [integer]      Number of the mh chain.
 %   name1           [string]       Object name.
-%   name2           [string]       Object name. 
-%    
-% OUTPUTS 
+%   name2           [string]       Object name.
+%
+% OUTPUTS
 %   None
-%        
+%
 % SPECIAL REQUIREMENTS
 
-% Copyright (C) 2003-2013 Dynare Team
+% Copyright (C) 2003-2017 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -35,10 +36,15 @@ function trace_plot(options_,M_,estim_params_,type,blck,name1,name2)
 % along with Dynare.  If not, see <http://www.gnu.org/licenses/>.
 
 % Cet the column index:
-if nargin<7    
-    column = name2index(options_, M_, estim_params_, type, name1);
+if strcmpi(type,'PosteriorDensity')
+    column=0;
+    name1='';
 else
-    column = name2index(options_, M_, estim_params_, type, name1, name2);
+    if nargin<7
+        column = name2index(options_, M_, estim_params_, type, name1);
+    else
+        column = name2index(options_, M_, estim_params_, type, name1, name2);
+    end
 end
 
 if isempty(column)
@@ -75,6 +81,8 @@ elseif strcmpi(type,'MeasurementError')
     else
         TYPE = 'the correlation between measurement errors ';
     end
+elseif strcmpi(type,'PosteriorDensity')
+    TYPE='the posterior density';
 end
 
 if nargin<7
@@ -84,10 +92,10 @@ else
 end
 
 if options_.mh_nblck>1
-    FigureName = [ FigureName , ' (block number ' int2str(blck)  ').']; 
+    FigureName = [ FigureName , ' (block number ' int2str(blck)  ').'];
 end
 
-hh=dyn_figure(options_,'Name',FigureName);
+hh=dyn_figure(options_.nodisplay,'Name',FigureName);
 plot(1:TotalNumberOfMhDraws,PosteriorDraws,'Color',[.7 .7 .7]);
 
 
@@ -99,7 +107,7 @@ first = N+1;
 last = TotalNumberOfMhDraws-N;
 
 for t=first:last
-    MovingAverage(t) = mean(PosteriorDraws(t-N:t+N)); 
+    MovingAverage(t) = mean(PosteriorDraws(t-N:t+N));
 end
 
 hold on
@@ -111,9 +119,51 @@ legend({'MCMC draw';[num2str(N) ' period moving average']},'Location','NorthWest
 if ~exist(M_.fname, 'dir')
     mkdir('.',M_.fname);
 end
-if ~exist([M_.fname filesep 'graphs'])
+if ~exist([M_.fname filesep 'graphs'],'dir')
     mkdir(M_.fname,'graphs');
 end
-plot_name=get_the_name(column,0,M_,estim_params_,options_);
-dyn_saveas(hh,[M_.fname, filesep, 'graphs', filesep, 'TracePlot_' plot_name],options_)
 
+%get name for plot
+if strcmpi(type,'PosteriorDensity')
+    plot_name='Posterior';
+else
+    plot_name=get_the_name(column,0,M_,estim_params_,options_);
+end
+plot_name=[plot_name,'_blck_',num2str(blck)];
+
+dyn_saveas(hh,[M_.fname, filesep, 'graphs', filesep, 'TracePlot_' plot_name],options_.nodisplay,options_.graph_format)
+
+if options_.TeX
+    fid=fopen([M_.fname,'/graphs/',M_.fname,'_TracePlot_' plot_name,'.tex'],'w+');
+
+    if strcmpi(type,'DeepParameter')
+        tex_names=M_.param_names_tex;
+        base_names=M_.param_names;
+    elseif strcmpi(type,'StructuralShock')
+        tex_names=M_.exo_names_tex;
+        base_names=M_.exo_names;
+    elseif strcmpi(type,'MeasurementError')
+        tex_names=M_.endo_names_tex;
+        base_names=M_.endo_names;
+    end
+
+    if strcmpi(type,'PosteriorDensity')
+        FigureName = ['Trace plot for ' TYPE name1];
+    else
+        if nargin<7
+            FigureName = ['Trace plot for ' TYPE '$' deblank(tex_names(strmatch(name1,base_names,'exact'),:)) '$'];
+        else
+            FigureName = ['Trace plot for ' TYPE '$' deblank(tex_names(strmatch(name1,base_names,'exact'),:)) '$ and $' deblank(tex_names(strmatch(name2,base_names,'exact'),:)) '$'];
+        end
+    end
+    if options_.mh_nblck>1
+        FigureName = [ FigureName , ' (block number ' int2str(blck)  ').'];
+    end
+
+    fprintf(fid,'%-s\n','\begin{figure}[H]');
+    fprintf(fid,'%-s\n','\centering');
+    fprintf(fid,'%-s\n',['  \includegraphics[width=0.8\textwidth]{',[M_.fname, '/graphs/TracePlot_' plot_name],'}\\']);
+    fprintf(fid,'%-s\n',['    \caption{',FigureName,'}']);
+    fprintf(fid,'%-s\n','\end{figure}');
+    fclose(fid);
+end
