@@ -3,14 +3,14 @@ function warning_config()
 %
 % INPUTS
 %   none
-%             
+%
 % OUTPUTS
 %   none
-%        
+%
 % SPECIAL REQUIREMENTS
 %   none
 
-% Copyright (C) 2008-2013 Dynare Team
+% Copyright (C) 2008-2017 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -34,7 +34,11 @@ warning('on', 'backtrace');
 
 if isoctave
     warning('off', 'Octave:separator-insert');
-    warning('off', 'Octave:matlab-incompatible');
+    if octave_ver_less_than('4.0')
+        warning('off', 'Octave:matlab-incompatible');
+    else
+        warning('off', 'Octave:language-extension');
+    end
     warning('off', 'Octave:single-quote-string');
     warning('off', 'Octave:missing-semicolon');
     warning('off', 'Octave:empty-list-elements');
@@ -43,11 +47,7 @@ if isoctave
     warning('off', 'Octave:str-to-num');
     warning('off', 'Octave:array-as-scalar');
     warning('off', 'Octave:array-as-vector');
-    if octave_ver_less_than('3.6')
-        warning('off', 'Octave:string-concat');
-    else
-        warning('off', 'Octave:mixed-string-concat');
-    end
+    warning('off', 'Octave:mixed-string-concat');
     warning('off', 'Octave:variable-switch-label');
     warning('off', 'Octave:fortran-indexing');
 else
