@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2014 Dynare Team
+ * Copyright (C) 2008-2017 Dynare Team
  *
  * This file is part of Dynare.
  *
@@ -62,14 +62,15 @@ DynareMxArrayToString(const mxArray *mxFldp, const int len, const int width, vec
         out[j] += cNamesCharStr[j+i*len];
 }
 
-void copy_derivatives(mxArray *destin,const Symmetry &sym,const FGSContainer *derivs,const std::string &fieldname)
+void
+copy_derivatives(mxArray *destin, const Symmetry &sym, const FGSContainer *derivs, const std::string &fieldname)
 {
-  const TwoDMatrix* x = derivs->get(sym);
+  const TwoDMatrix *x = derivs->get(sym);
   int n = x->numRows();
   int m = x->numCols();
   mxArray *tmp = mxCreateDoubleMatrix(n, m, mxREAL);
-  memcpy(mxGetPr(tmp),x->getData().base(),n*m*sizeof(double));
-  mxSetField(destin,0,fieldname.c_str(),tmp);
+  memcpy(mxGetPr(tmp), x->getData().base(), n*m*sizeof(double));
+  mxSetField(destin, 0, fieldname.c_str(), tmp);
 }
 
 extern "C" {
@@ -176,7 +177,7 @@ extern "C" {
     //get NNZH =NNZD(2) = the total number of non-zero Hessian elements
     mxFldp = mxGetField(M_, 0, "NNZDerivatives");
     dparams = mxGetPr(mxFldp);
-    Vector NNZD(dparams, (int) mxGetM(mxFldp));
+    Vector NNZD(dparams, (int)mxGetM(mxFldp));
     if (NNZD[kOrder-1] == -1)
       DYN_MEX_FUNC_ERR_MSG_TXT("The derivatives were not computed for the required order. Make sure that you used the right order option inside the stoch_simul command");
 
@@ -197,32 +198,31 @@ extern "C" {
     if ((nEndo != nendo) || (nExog != nexo))
       DYN_MEX_FUNC_ERR_MSG_TXT("Incorrect number of input parameters.");
 
-    TwoDMatrix *g1m=NULL;
-    TwoDMatrix *g2m=NULL;
-    TwoDMatrix *g3m=NULL;
+    TwoDMatrix *g1m = NULL;
+    TwoDMatrix *g2m = NULL;
+    TwoDMatrix *g3m = NULL;
     // derivatives passed as arguments */
-    if (nrhs > 3) 
+    if (nrhs > 3)
       {
-	const mxArray *g1 = prhs[3];
-	int m = (int) mxGetM(g1);
-	int n = (int) mxGetN(g1);
-	g1m = new TwoDMatrix(m, n, mxGetPr(g1));
-	if (nrhs > 4)
-	  {
-	    const mxArray *g2 = prhs[4];
-	    int m = (int) mxGetM(g2);
-	    int n = (int) mxGetN(g2);
-	    g2m = new TwoDMatrix(m, n, mxGetPr(g2));
-	    if (nrhs > 5)
-	      {
-		const mxArray *g3 = prhs[5];
-		int m = (int) mxGetM(g3);
-		int n = (int) mxGetN(g3);
-		g3m = new TwoDMatrix(m, n, mxGetPr(g3));
-	      }
-	  }
+        const mxArray *g1 = prhs[3];
+        int m = (int) mxGetM(g1);
+        int n = (int) mxGetN(g1);
+        g1m = new TwoDMatrix(m, n, mxGetPr(g1));
+        if (nrhs > 4)
+          {
+            const mxArray *g2 = prhs[4];
+            int m = (int) mxGetM(g2);
+            int n = (int) mxGetN(g2);
+            g2m = new TwoDMatrix(m, n, mxGetPr(g2));
+            if (nrhs > 5)
+              {
+                const mxArray *g3 = prhs[5];
+                int m = (int) mxGetM(g3);
+                int n = (int) mxGetN(g3);
+                g3m = new TwoDMatrix(m, n, mxGetPr(g3));
+              }
+          }
       }
-	    
 
     const int nSteps = 0; // Dynare++ solving steps, for time being default to 0 = deterministic steady state
     const double sstol = 1.e-13; //NL solver tolerance from
@@ -250,7 +250,7 @@ extern "C" {
                            ySteady, vCov, modParams, nStat, nPred, nForw, nBoth,
                            jcols, NNZD, nSteps, kOrder, journal, dynamicModelFile,
                            sstol, var_order_vp, llincidence, qz_criterium,
-			   g1m, g2m, g3m);
+                           g1m, g2m, g3m);
 
         // construct main K-order approximation class
 
@@ -283,40 +283,40 @@ extern "C" {
             for (map<string, ConstTwoDMatrix>::const_iterator cit = mm.begin();
                  ((cit != mm.end()) && (ii < nlhs)); ++cit)
               {
-		plhs[ii] = mxCreateDoubleMatrix((*cit).second.numRows(), (*cit).second.numCols(), mxREAL);
-		
-		// Copy Dynare++ matrix into MATLAB matrix
-		const ConstVector &vec = (*cit).second.getData();
-		assert(vec.skip() == 1);
-		memcpy(mxGetPr(plhs[ii]), vec.base(), vec.length() * sizeof(double));
-		
-		++ii;
-		
+                plhs[ii] = mxCreateDoubleMatrix((*cit).second.numRows(), (*cit).second.numCols(), mxREAL);
+
+                // Copy Dynare++ matrix into MATLAB matrix
+                const ConstVector &vec = (*cit).second.getData();
+                assert(vec.skip() == 1);
+                memcpy(mxGetPr(plhs[ii]), vec.base(), vec.length() * sizeof(double));
+
+                ++ii;
+
               }
-	    if (kOrder == 3 && nlhs > 4)
-	      {
-		const FGSContainer *derivs = app.get_rule_ders();
-		const std::string fieldnames[] = {"gy", "gu", "gyy", "gyu", "guu", "gss", 
-				      "gyyy", "gyyu", "gyuu", "guuu", "gyss", "guss"};
-		// creates the char** expected by mxCreateStructMatrix()
-		const char* c_fieldnames[12];
-		for (int i=0; i < 12;++i)
-		  c_fieldnames[i] = fieldnames[i].c_str();
-		plhs[ii] = mxCreateStructMatrix(1,1,12,c_fieldnames);
-		copy_derivatives(plhs[ii],Symmetry(1,0,0,0),derivs,"gy");
-		copy_derivatives(plhs[ii],Symmetry(0,1,0,0),derivs,"gu");
-		copy_derivatives(plhs[ii],Symmetry(2,0,0,0),derivs,"gyy");
-		copy_derivatives(plhs[ii],Symmetry(0,2,0,0),derivs,"guu");
-		copy_derivatives(plhs[ii],Symmetry(1,1,0,0),derivs,"gyu");
-		copy_derivatives(plhs[ii],Symmetry(0,0,0,2),derivs,"gss");
-		copy_derivatives(plhs[ii],Symmetry(3,0,0,0),derivs,"gyyy");
-		copy_derivatives(plhs[ii],Symmetry(0,3,0,0),derivs,"guuu");
-		copy_derivatives(plhs[ii],Symmetry(2,1,0,0),derivs,"gyyu");
-		copy_derivatives(plhs[ii],Symmetry(1,2,0,0),derivs,"gyuu");
-		copy_derivatives(plhs[ii],Symmetry(1,0,0,2),derivs,"gyss");
-		copy_derivatives(plhs[ii],Symmetry(0,1,0,2),derivs,"guss");
-	      }
-	  }
+            if (kOrder == 3 && nlhs > 4)
+              {
+                const FGSContainer *derivs = app.get_rule_ders();
+                const std::string fieldnames[] = {"gy", "gu", "gyy", "gyu", "guu", "gss",
+                                                  "gyyy", "gyyu", "gyuu", "guuu", "gyss", "guss"};
+                // creates the char** expected by mxCreateStructMatrix()
+                const char *c_fieldnames[12];
+                for (int i = 0; i < 12; ++i)
+                  c_fieldnames[i] = fieldnames[i].c_str();
+                plhs[ii] = mxCreateStructMatrix(1, 1, 12, c_fieldnames);
+                copy_derivatives(plhs[ii], Symmetry(1, 0, 0, 0), derivs, "gy");
+                copy_derivatives(plhs[ii], Symmetry(0, 1, 0, 0), derivs, "gu");
+                copy_derivatives(plhs[ii], Symmetry(2, 0, 0, 0), derivs, "gyy");
+                copy_derivatives(plhs[ii], Symmetry(0, 2, 0, 0), derivs, "guu");
+                copy_derivatives(plhs[ii], Symmetry(1, 1, 0, 0), derivs, "gyu");
+                copy_derivatives(plhs[ii], Symmetry(0, 0, 0, 2), derivs, "gss");
+                copy_derivatives(plhs[ii], Symmetry(3, 0, 0, 0), derivs, "gyyy");
+                copy_derivatives(plhs[ii], Symmetry(0, 3, 0, 0), derivs, "guuu");
+                copy_derivatives(plhs[ii], Symmetry(2, 1, 0, 0), derivs, "gyyu");
+                copy_derivatives(plhs[ii], Symmetry(1, 2, 0, 0), derivs, "gyuu");
+                copy_derivatives(plhs[ii], Symmetry(1, 0, 0, 2), derivs, "gyss");
+                copy_derivatives(plhs[ii], Symmetry(0, 1, 0, 2), derivs, "guss");
+              }
+          }
       }
     catch (const KordException &e)
       {
