@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2013 Dynare Team
+ * Copyright (C) 2003-2017 Dynare Team
  *
  * This file is part of Dynare.
  *
@@ -36,7 +36,7 @@ using namespace MFS;
 bool
 ModelTree::computeNormalization(const jacob_map_t &contemporaneous_jacobian, bool verbose)
 {
-  const int n = equation_number();
+  const int n = equations.size();
 
   assert(n == symbol_table.endo_nbr());
 
@@ -96,7 +96,7 @@ ModelTree::computeNormalization(const jacob_map_t &contemporaneous_jacobian, boo
 #endif
 
   // Create the resulting map, by copying the n first elements of mate_map, and substracting n to them
-  endo2eq.resize(equation_number());
+  endo2eq.resize(equations.size());
   transform(mate_map.begin(), mate_map.begin() + n, endo2eq.begin(), bind2nd(minus<int>(), n));
 
 #ifdef DEBUG
@@ -143,7 +143,7 @@ ModelTree::computeNonSingularNormalization(jacob_map_t &contemporaneous_jacobian
 
   cout << "Normalizing the model..." << endl;
 
-  int n = equation_number();
+  int n = equations.size();
 
   // compute the maximum value of each row of the contemporaneous Jacobian matrix
   //jacob_map normalized_contemporaneous_jacobian;
@@ -212,7 +212,7 @@ ModelTree::computeNonSingularNormalization(jacob_map_t &contemporaneous_jacobian
                   if (first_derivatives.find(make_pair(it->first.first, getDerivID(symbol_table.getID(eEndogenous, it->first.second), 0))) == first_derivatives.end())
                     first_derivatives[make_pair(it->first.first, getDerivID(symbol_table.getID(eEndogenous, it->first.second), 0))] = Zero;
                 }
-              catch(DataTree::UnknownDerivIDException &e)
+              catch (DataTree::UnknownDerivIDException &e)
                 {
                   cerr << "The variable " << symbol_table.getName(symbol_table.getID(eEndogenous, it->first.second))
                        << " does not appear at the current period (i.e. with no lead and no lag); this case is not handled by the 'block' option of the 'model' block." << endl;
@@ -232,7 +232,7 @@ ModelTree::computeNonSingularNormalization(jacob_map_t &contemporaneous_jacobian
 void
 ModelTree::computeNormalizedEquations(multimap<int, int> &endo2eqs) const
 {
-  for (int i = 0; i < equation_number(); i++)
+  for (size_t i = 0; i < equations.size(); i++)
     {
       VariableNode *lhs = dynamic_cast<VariableNode *>(equations[i]->get_arg1());
       if (lhs == NULL)
@@ -247,7 +247,7 @@ ModelTree::computeNormalizedEquations(multimap<int, int> &endo2eqs) const
       if (endo.find(make_pair(symbol_table.getTypeSpecificID(symb_id), 0)) != endo.end())
         continue;
 
-      endo2eqs.insert(make_pair(symbol_table.getTypeSpecificID(symb_id), i));
+      endo2eqs.insert(make_pair(symbol_table.getTypeSpecificID(symb_id), (int) i));
       cout << "Endogenous " << symbol_table.getName(symb_id) << " normalized in equation " << (i+1) << endl;
     }
 }
@@ -279,7 +279,7 @@ ModelTree::evaluateAndReduceJacobian(const eval_context_t &eval_context, jacob_m
             }
           catch (ExprNode::EvalException &e)
             {
-              cerr << "ERROR: evaluation of Jacobian failed for equation " << eq+1 << " and variable " << symbol_table.getName(symb) << "(" << lag << ") [" << symb << "] !" << endl;
+              cerr << "ERROR: evaluation of Jacobian failed for equation " << eq+1 << " (line " << equations_lineno[eq] << ") and variable " << symbol_table.getName(symb) << "(" << lag << ") [" << symb << "] !" << endl;
               Id->writeOutput(cerr, oMatlabDynamicModelSparse, temporary_terms);
               cerr << endl;
               exit(EXIT_FAILURE);
@@ -320,11 +320,11 @@ ModelTree::evaluateAndReduceJacobian(const eval_context_t &eval_context, jacob_m
 void
 ModelTree::computePrologueAndEpilogue(const jacob_map_t &static_jacobian_arg, vector<int> &equation_reordered, vector<int> &variable_reordered)
 {
-  vector<int> eq2endo(equation_number(), 0);
-  equation_reordered.resize(equation_number());
-  variable_reordered.resize(equation_number());
+  vector<int> eq2endo(equations.size(), 0);
+  equation_reordered.resize(equations.size());
+  variable_reordered.resize(equations.size());
   bool *IM;
-  int n = equation_number();
+  int n = equations.size();
   IM = (bool *) calloc(n*n, sizeof(bool));
   int i = 0;
   for (vector<int>::const_iterator it = endo2eq.begin(); it != endo2eq.end(); it++, i++)
@@ -333,8 +333,20 @@ ModelTree::computePrologueAndEpilogue(const jacob_map_t &static_jacobian_arg, ve
       equation_reordered[i] = i;
       variable_reordered[*it] = i;
     }
-  for (jacob_map_t::const_iterator it = static_jacobian_arg.begin(); it != static_jacobian_arg.end(); it++)
-    IM[it->first.first * n + endo2eq[it->first.second]] = true;
+  if (cutoff == 0)
+    {
+      set<pair<int, int> > endo;
+      for (int i = 0; i < n; i++)
+        {
+          endo.clear();
+          equations[i]->collectEndogenous(endo);
+          for (set<pair<int, int> >::const_iterator it = endo.begin(); it != endo.end(); it++)
+            IM[i * n + endo2eq[it->first]] = true;
+        }
+    }
+  else
+    for (jacob_map_t::const_iterator it = static_jacobian_arg.begin(); it != static_jacobian_arg.end(); it++)
+      IM[it->first.first * n + endo2eq[it->first.second]] = true;
   bool something_has_been_done = true;
   prologue = 0;
   int k = 0;
@@ -535,8 +547,22 @@ ModelTree::computeBlockDecompositionAndFeedbackVariablesForEachBlock(const jacob
       reverse_equation_reordered[equation_reordered[i]] = i;
       reverse_variable_reordered[variable_reordered[i]] = i;
     }
+  jacob_map_t tmp_normalized_contemporaneous_jacobian;
+  if (cutoff == 0)
+    {
+      set<pair<int, int> > endo;
+      for (int i = 0; i < nb_var; i++)
+        {
+          endo.clear();
+          equations[i]->collectEndogenous(endo);
+          for (set<pair<int, int> >::const_iterator it = endo.begin(); it != endo.end(); it++)
+            tmp_normalized_contemporaneous_jacobian[make_pair(i, it->first)] = 1;
 
-  for (jacob_map_t::const_iterator it = static_jacobian.begin(); it != static_jacobian.end(); it++)
+        }
+    }
+  else
+    tmp_normalized_contemporaneous_jacobian = static_jacobian;
+  for (jacob_map_t::const_iterator it = tmp_normalized_contemporaneous_jacobian.begin(); it != tmp_normalized_contemporaneous_jacobian.end(); it++)
     if (reverse_equation_reordered[it->first.first] >= (int) prologue && reverse_equation_reordered[it->first.first] < (int) (nb_var - epilogue)
         && reverse_variable_reordered[it->first.second] >= (int) prologue && reverse_variable_reordered[it->first.second] < (int) (nb_var - epilogue)
         && it->first.first != endo2eq[it->first.second])
@@ -861,7 +887,7 @@ ModelTree::reduceBlocksAndTypeDetermination(const dynamic_jacob_map_t &dynamic_j
               int c_Size = (block_type_size_mfs[block_type_size_mfs.size()-1]).second.first;
               int first_equation = (block_type_size_mfs[block_type_size_mfs.size()-1]).first.second;
               if (c_Size > 0 && ((prev_Type ==  EVALUATE_FORWARD && Simulation_Type == EVALUATE_FORWARD && !is_lead)
-                  || (prev_Type ==  EVALUATE_BACKWARD && Simulation_Type == EVALUATE_BACKWARD && !is_lag)))
+                                 || (prev_Type ==  EVALUATE_BACKWARD && Simulation_Type == EVALUATE_BACKWARD && !is_lag)))
                 {
                   for (int j = first_equation; j < first_equation+c_Size; j++)
                     {
@@ -1019,7 +1045,7 @@ ModelTree::computeJacobian(const set<int> &vars)
             continue;
           first_derivatives[make_pair(eq, *it)] = d1;
           ++NNZDerivatives[0];
-        } 
+        }
     }
 }
 
@@ -1092,55 +1118,203 @@ ModelTree::computeThirdDerivatives(const set<int> &vars)
 void
 ModelTree::computeTemporaryTerms(bool is_matlab)
 {
-  map<expr_t, int> reference_count;
+  map<expr_t, pair<int, NodeTreeReference> > reference_count;
   temporary_terms.clear();
+  temporary_terms_res.clear();
+  temporary_terms_g1.clear();
+  temporary_terms_g2.clear();
+  temporary_terms_g3.clear();
+  map<NodeTreeReference, temporary_terms_t> temp_terms_map;
+  temp_terms_map[eResiduals] = temporary_terms_res;
+  temp_terms_map[eFirstDeriv] = temporary_terms_g1;
+  temp_terms_map[eSecondDeriv] = temporary_terms_g2;
+  temp_terms_map[eThirdDeriv] = temporary_terms_g3;
 
   for (vector<BinaryOpNode *>::iterator it = equations.begin();
        it != equations.end(); it++)
-    (*it)->computeTemporaryTerms(reference_count, temporary_terms, is_matlab);
+    (*it)->computeTemporaryTerms(reference_count,
+                                 temp_terms_map,
+                                 is_matlab, eResiduals);
 
   for (first_derivatives_t::iterator it = first_derivatives.begin();
        it != first_derivatives.end(); it++)
-    it->second->computeTemporaryTerms(reference_count, temporary_terms, is_matlab);
+    it->second->computeTemporaryTerms(reference_count,
+                                      temp_terms_map,
+                                      is_matlab, eFirstDeriv);
 
   for (second_derivatives_t::iterator it = second_derivatives.begin();
        it != second_derivatives.end(); it++)
-    it->second->computeTemporaryTerms(reference_count, temporary_terms, is_matlab);
+    it->second->computeTemporaryTerms(reference_count,
+                                      temp_terms_map,
+                                      is_matlab, eSecondDeriv);
 
   for (third_derivatives_t::iterator it = third_derivatives.begin();
        it != third_derivatives.end(); it++)
-    it->second->computeTemporaryTerms(reference_count, temporary_terms, is_matlab);
+    it->second->computeTemporaryTerms(reference_count,
+                                      temp_terms_map,
+                                      is_matlab, eThirdDeriv);
+
+  for (map<NodeTreeReference, temporary_terms_t>::const_iterator it = temp_terms_map.begin();
+       it != temp_terms_map.end(); it++)
+    temporary_terms.insert(it->second.begin(), it->second.end());
+
+  temporary_terms_res = temp_terms_map[eResiduals];
+  temporary_terms_g1  = temp_terms_map[eFirstDeriv];
+  temporary_terms_g2  = temp_terms_map[eSecondDeriv];
+  temporary_terms_g3  = temp_terms_map[eThirdDeriv];
 }
 
 void
-ModelTree::writeTemporaryTerms(const temporary_terms_t &tt, ostream &output,
+ModelTree::writeTemporaryTerms(const temporary_terms_t &tt, const temporary_terms_t &ttm1, ostream &output,
                                ExprNodeOutputType output_type, deriv_node_temp_terms_t &tef_terms) const
 {
   // Local var used to keep track of temp nodes already written
-  temporary_terms_t tt2;
-
+  temporary_terms_t tt2 = ttm1;
   for (temporary_terms_t::const_iterator it = tt.begin();
        it != tt.end(); it++)
+    if (ttm1.find(*it) == ttm1.end())
+      {
+        if (dynamic_cast<AbstractExternalFunctionNode *>(*it) != NULL)
+          (*it)->writeExternalFunctionOutput(output, output_type, tt2, tef_terms);
+
+        if (IS_C(output_type))
+          output << "double ";
+        else if (IS_JULIA(output_type))
+          output << "  @inbounds const ";
+
+        (*it)->writeOutput(output, output_type, tt, tef_terms);
+        output << " = ";
+        (*it)->writeOutput(output, output_type, tt2, tef_terms);
+
+        if (IS_C(output_type) || IS_MATLAB(output_type))
+          output << ";";
+        output << endl;
+
+        // Insert current node into tt2
+        tt2.insert(*it);
+      }
+}
+
+void
+ModelTree::fixNestedParenthesis(ostringstream &output, map<string, string> &tmp_paren_vars, bool &message_printed) const
+{
+  string str = output.str();
+  if (!testNestedParenthesis(str))
+    return;
+  int open = 0;
+  int first_open_paren = 0;
+  int matching_paren = 0;
+  bool hit_limit = false;
+  int i1 = 0;
+  map<string, string>::iterator it;
+  for (size_t i = 0; i < str.length(); i++)
     {
-      if (dynamic_cast<AbstractExternalFunctionNode *>(*it) != NULL)
-        (*it)->writeExternalFunctionOutput(output, output_type, tt2, tef_terms);
+      if (str.at(i) == '(')
+        {
+          if (open == 0)
+            first_open_paren = i;
+          open++;
+        }
+      else if (str.at(i) == ')')
+        {
+          open--;
+          if (open == 0)
+            matching_paren = i;
+        }
+      if (open > 32)
+        hit_limit = true;
 
-      if (IS_C(output_type))
-        output << "double ";
+      if (hit_limit && open == 0)
+        {
+          if (!message_printed)
+            {
+              cerr << "Warning: A .m file created by Dynare will have more than 32 nested parenthesis. Matlab cannot support this. " << endl
+                   << "         We are going to modify, albeit inefficiently, this output to have fewer than 32 nested parenthesis. " << endl
+                   << "         It would hence behoove you to use the use_dll option of the model block to circumnavigate this problem." << endl
+                   << "         If you have not yet set up a compiler on your system, see the Matlab documentation for doing so." << endl
+                   << "         For Windows, see: https://www.mathworks.com/help/matlab/matlab_external/install-mingw-support-package.html" << endl << endl;
+              message_printed = true;
+            }
+          string str1 = str.substr(first_open_paren, matching_paren - first_open_paren + 1);
+          string repstr = "";
+          string varname;
+          while (testNestedParenthesis(str1))
+            {
+              size_t open_paren_idx  = string::npos;
+              size_t match_paren_idx = string::npos;
+              size_t last_open_paren = string::npos;
+              for (size_t j = 0; j < str1.length(); j++)
+                {
+                  if (str1.at(j) == '(')
+                    {
+                      // don't match, e.g. y(1)
+                      size_t idx = str1.find_last_of("*/-+", j - 1);
+                      if (j == 0 || (idx != string::npos && idx == j - 1))
+                        open_paren_idx = j;
+                      last_open_paren = j;
+                    }
+                  else if (str1.at(j) == ')')
+                    {
+                      // don't match, e.g. y(1)
+                      size_t idx = str1.find_last_not_of("0123456789", j - 1);
+                      if (idx != string::npos && idx != last_open_paren)
+                        match_paren_idx = j;
+                    }
 
-      (*it)->writeOutput(output, output_type, tt, tef_terms);
-      output << " = ";
-      (*it)->writeOutput(output, output_type, tt2, tef_terms);
-
-      if (IS_C(output_type))
-        output << ";" << endl;
-
-      // Insert current node into tt2
-      tt2.insert(*it);
-
-      if (IS_MATLAB(output_type))
-        output << ";" << endl;
+                  if (open_paren_idx != string::npos && match_paren_idx != string::npos)
+                    {
+                      string val = str1.substr(open_paren_idx, match_paren_idx - open_paren_idx + 1);
+                      it = tmp_paren_vars.find(val);
+                      if (it == tmp_paren_vars.end())
+                        {
+                          ostringstream ptvstr;
+                          ptvstr << i1++;
+                          varname = "paren32_tmp_var_" + ptvstr.str();
+                          repstr = repstr + varname + " = " + val + ";\n";
+                          tmp_paren_vars[val] = varname;
+                        }
+                      else
+                        varname = it->second;
+                      str1.replace(open_paren_idx, match_paren_idx - open_paren_idx + 1, varname);
+                      break;
+                    }
+                }
+            }
+          it = tmp_paren_vars.find(str1);
+          if (it == tmp_paren_vars.end())
+            {
+              ostringstream ptvstr;
+              ptvstr << i1++;
+              varname = "paren32_tmp_var_" + ptvstr.str();
+              repstr = repstr + varname + " = " + str1 + ";\n";
+            }
+          else
+            varname = it->second;
+          str.replace(first_open_paren, matching_paren - first_open_paren + 1, varname);
+          size_t insertLoc = str.find_last_of("\n", first_open_paren);
+          str.insert(insertLoc + 1, repstr);
+          hit_limit = false;
+          i = -1;
+          first_open_paren = matching_paren = open = 0;
+        }
     }
+  output.str(str);
+}
+
+bool
+ModelTree::testNestedParenthesis(const string &str) const
+{
+  int open = 0;
+  for (size_t i = 0; i < str.length(); i++)
+    {
+      if (str.at(i) == '(')
+        open++;
+      else if (str.at(i) == ')')
+        open--;
+      if (open > 32)
+        return true;
+    }
+  return false;
 }
 
 void
@@ -1158,17 +1332,17 @@ ModelTree::compileTemporaryTerms(ostream &code_file, unsigned int &instruction_n
           (*it)->compileExternalFunctionOutput(code_file, instruction_number, false, tt2, map_idx, dynamic, steady_dynamic, tef_terms);
         }
 
-      FNUMEXPR_ fnumexpr(TemporaryTerm, (int) (map_idx.find((*it)->idx)->second));
+      FNUMEXPR_ fnumexpr(TemporaryTerm, (int)(map_idx.find((*it)->idx)->second));
       fnumexpr.write(code_file, instruction_number);
       (*it)->compile(code_file, instruction_number, false, tt2, map_idx, dynamic, steady_dynamic, tef_terms);
       if (dynamic)
         {
-          FSTPT_ fstpt((int) (map_idx.find((*it)->idx)->second));
+          FSTPT_ fstpt((int)(map_idx.find((*it)->idx)->second));
           fstpt.write(code_file, instruction_number);
         }
       else
         {
-          FSTPST_ fstpst((int) (map_idx.find((*it)->idx)->second));
+          FSTPST_ fstpst((int)(map_idx.find((*it)->idx)->second));
           fstpst.write(code_file, instruction_number);
         }
       // Insert current node into tt2
@@ -1199,6 +1373,8 @@ ModelTree::writeModelLocalVariables(ostream &output, ExprNodeOutputType output_t
 
       if (IS_C(output_type))
         output << "double ";
+      else if (IS_JULIA(output_type))
+        output << "  @inbounds ";
 
       /* We append underscores to avoid name clashes with "g1" or "oo_" (see
          also VariableNode::writeOutput) */
@@ -1211,6 +1387,12 @@ ModelTree::writeModelLocalVariables(ostream &output, ExprNodeOutputType output_t
 void
 ModelTree::writeModelEquations(ostream &output, ExprNodeOutputType output_type) const
 {
+  temporary_terms_t temp_terms;
+  if (IS_JULIA(output_type))
+    temp_terms = temporary_terms_res;
+  else
+    temp_terms = temporary_terms;
+
   for (int eq = 0; eq < (int) equations.size(); eq++)
     {
       BinaryOpNode *eq_node = equations[eq];
@@ -1229,14 +1411,20 @@ ModelTree::writeModelEquations(ostream &output, ExprNodeOutputType output_type)
 
       if (vrhs != 0) // The right hand side of the equation is not empty ==> residual=lhs-rhs;
         {
+          if (IS_JULIA(output_type))
+            output << "  @inbounds ";
           output << "lhs =";
-          lhs->writeOutput(output, output_type, temporary_terms);
+          lhs->writeOutput(output, output_type, temp_terms);
           output << ";" << endl;
 
+          if (IS_JULIA(output_type))
+            output << "  @inbounds ";
           output << "rhs =";
-          rhs->writeOutput(output, output_type, temporary_terms);
+          rhs->writeOutput(output, output_type, temp_terms);
           output << ";" << endl;
 
+          if (IS_JULIA(output_type))
+            output << "  @inbounds ";
           output << "residual" << LEFT_ARRAY_SUBSCRIPT(output_type)
                  << eq + ARRAY_SUBSCRIPT_OFFSET(output_type)
                  << RIGHT_ARRAY_SUBSCRIPT(output_type)
@@ -1244,11 +1432,13 @@ ModelTree::writeModelEquations(ostream &output, ExprNodeOutputType output_type)
         }
       else // The right hand side of the equation is empty ==> residual=lhs;
         {
+          if (IS_JULIA(output_type))
+            output << "  @inbounds ";
           output << "residual" << LEFT_ARRAY_SUBSCRIPT(output_type)
                  << eq + ARRAY_SUBSCRIPT_OFFSET(output_type)
                  << RIGHT_ARRAY_SUBSCRIPT(output_type)
                  << " = ";
-          lhs->writeOutput(output, output_type, temporary_terms);
+          lhs->writeOutput(output, output_type, temp_terms);
           output << ";" << endl;
         }
     }
@@ -1307,7 +1497,7 @@ ModelTree::Write_Inf_To_Bin_File(const string &basename,
     SaveCode.open(bin_basename.c_str(), ios::out | ios::binary);
   if (!SaveCode.is_open())
     {
-      cout << "Error : Can't open file \"" << bin_basename << "\" for writing\n";
+      cerr << "Error : Can't open file \"" << bin_basename << "\" for writing" << endl;
       exit(EXIT_FAILURE);
     }
   u_count_int = 0;
@@ -1339,9 +1529,12 @@ ModelTree::Write_Inf_To_Bin_File(const string &basename,
 }
 
 void
-ModelTree::writeLatexModelFile(const string &filename, ExprNodeOutputType output_type) const
+ModelTree::writeLatexModelFile(const string &basename, ExprNodeOutputType output_type, const bool write_equation_tags) const
 {
-  ofstream output;
+  ofstream output, content_output;
+  string filename = basename + ".tex";
+  string content_basename = basename + "_content";
+  string content_filename = content_basename + ".tex";
   output.open(filename.c_str(), ios::out | ios::binary);
   if (!output.is_open())
     {
@@ -1349,9 +1542,17 @@ ModelTree::writeLatexModelFile(const string &filename, ExprNodeOutputType output
       exit(EXIT_FAILURE);
     }
 
+  content_output.open(content_filename.c_str(), ios::out | ios::binary);
+  if (!content_output.is_open())
+    {
+      cerr << "ERROR: Can't open file " << content_filename << " for writing" << endl;
+      exit(EXIT_FAILURE);
+    }
+
   output << "\\documentclass[10pt,a4paper]{article}" << endl
          << "\\usepackage[landscape]{geometry}" << endl
          << "\\usepackage{fullpage}" << endl
+         << "\\usepackage{amsfonts}" << endl
          << "\\usepackage{breqn}" << endl
          << "\\begin{document}" << endl
          << "\\footnotesize" << endl;
@@ -1363,43 +1564,69 @@ ModelTree::writeLatexModelFile(const string &filename, ExprNodeOutputType output
       int id = it->first;
       expr_t value = it->second;
 
-      output << "\\begin{dmath*}" << endl
-             << symbol_table.getName(id) << " = ";
+      content_output << "\\begin{dmath*}" << endl
+                     << symbol_table.getTeXName(id) << " = ";
       // Use an empty set for the temporary terms
-      value->writeOutput(output, output_type);
-      output << endl << "\\end{dmath*}" << endl;
+      value->writeOutput(content_output, output_type);
+      content_output << endl << "\\end{dmath*}" << endl;
     }
 
   for (int eq = 0; eq < (int) equations.size(); eq++)
     {
-      output << "\\begin{dmath}" << endl
-             << "% Equation " << eq+1 << endl;
+      content_output << "% Equation " << eq + 1 << endl;
+      bool wrote_eq_tag = false;
+      if (write_equation_tags)
+        {
+          for (vector<pair<int, pair<string, string> > >::const_iterator iteqt = equation_tags.begin();
+               iteqt != equation_tags.end(); iteqt++)
+            if (iteqt->first == eq)
+              {
+                if (!wrote_eq_tag)
+                  content_output << "\\noindent[";
+                else
+                  content_output << ", ";
+
+                content_output << iteqt->second.first;
+
+                if (iteqt->second.second.empty())
+                  content_output << "= `" << iteqt->second.second << "'";
+
+                wrote_eq_tag = true;
+              }
+        }
+      if (wrote_eq_tag)
+        content_output << "]";
+
+      content_output << "\\begin{dmath}" << endl;
       // Here it is necessary to cast to superclass ExprNode, otherwise the overloaded writeOutput() method is not found
-      dynamic_cast<ExprNode *>(equations[eq])->writeOutput(output, output_type);
-      output << endl << "\\end{dmath}" << endl;
+      dynamic_cast<ExprNode *>(equations[eq])->writeOutput(content_output, output_type);
+      content_output << endl << "\\end{dmath}" << endl;
     }
 
-  output << "\\end{document}" << endl;
+  output << "\\include{" << content_basename << "}" << endl
+         << "\\end{document}" << endl;
 
   output.close();
+  content_output.close();
 }
 
 void
-ModelTree::addEquation(expr_t eq)
+ModelTree::addEquation(expr_t eq, int lineno)
 {
   BinaryOpNode *beq = dynamic_cast<BinaryOpNode *>(eq);
   assert(beq != NULL && beq->get_op_code() == oEqual);
 
   equations.push_back(beq);
+  equations_lineno.push_back(lineno);
 }
 
 void
-ModelTree::addEquation(expr_t eq, vector<pair<string, string> > &eq_tags)
+ModelTree::addEquation(expr_t eq, int lineno, vector<pair<string, string> > &eq_tags)
 {
-  int n = equation_number();
+  int n = equations.size();
   for (size_t i = 0; i < eq_tags.size(); i++)
     equation_tags.push_back(make_pair(n, eq_tags[i]));
-  addEquation(eq);
+  addEquation(eq, lineno);
 }
 
 void
@@ -1440,7 +1667,7 @@ ModelTree::addNonstationaryVariables(vector<int> nonstationary_vars, bool log_de
 void
 ModelTree::initializeVariablesAndEquations()
 {
-  for (int j = 0; j < equation_number(); j++)
+  for (size_t j = 0; j < equations.size(); j++)
     {
       equation_reordered.push_back(j);
       variable_reordered.push_back(j);
@@ -1456,8 +1683,11 @@ ModelTree::set_cutoff_to_zero()
 void
 ModelTree::jacobianHelper(ostream &output, int eq_nb, int col_nb, ExprNodeOutputType output_type) const
 {
-  output << "  g1" << LEFT_ARRAY_SUBSCRIPT(output_type);
-  if (IS_MATLAB(output_type))
+  output << "  ";
+  if (IS_JULIA(output_type))
+    output << "@inbounds ";
+  output << "g1" << LEFT_ARRAY_SUBSCRIPT(output_type);
+  if (IS_MATLAB(output_type) || IS_JULIA(output_type))
     output << eq_nb + 1 << "," << col_nb + 1;
   else
     output << eq_nb + col_nb *equations.size();
@@ -1468,7 +1698,7 @@ void
 ModelTree::sparseHelper(int order, ostream &output, int row_nb, int col_nb, ExprNodeOutputType output_type) const
 {
   output << "  v" << order << LEFT_ARRAY_SUBSCRIPT(output_type);
-  if (IS_MATLAB(output_type))
+  if (IS_MATLAB(output_type) || IS_JULIA(output_type))
     output << row_nb + 1 << "," << col_nb + 1;
   else
     output << row_nb + col_nb * NNZDerivatives[order-1];
@@ -1476,11 +1706,13 @@ ModelTree::sparseHelper(int order, ostream &output, int row_nb, int col_nb, Expr
 }
 
 void
-ModelTree::computeParamsDerivatives()
+ModelTree::computeParamsDerivatives(int paramsDerivsOrder)
 {
+  if (!(paramsDerivsOrder == 1 || paramsDerivsOrder == 2))
+    return;
   set<int> deriv_id_set;
   addAllParamDerivId(deriv_id_set);
-  
+
   for (set<int>::const_iterator it = deriv_id_set.begin();
        it != deriv_id_set.end(); it++)
     {
@@ -1494,18 +1726,19 @@ ModelTree::computeParamsDerivatives()
           residuals_params_derivatives[make_pair(eq, param)] = d1;
         }
 
-      for (first_derivatives_t::const_iterator it2 = residuals_params_derivatives.begin();
-           it2 != residuals_params_derivatives.end(); it2++)
-        {
-          int eq = it2->first.first;
-          int param1 = it2->first.second;
-          expr_t d1 = it2->second;
+      if (paramsDerivsOrder == 2)
+        for (first_derivatives_t::const_iterator it2 = residuals_params_derivatives.begin();
+             it2 != residuals_params_derivatives.end(); it2++)
+          {
+            int eq = it2->first.first;
+            int param1 = it2->first.second;
+            expr_t d1 = it2->second;
 
-          expr_t d2 = d1->getDerivative(param);
-          if (d2 == Zero)
-            continue;
-          residuals_params_second_derivatives[make_pair(eq, make_pair(param1, param))] = d2;
-        }
+            expr_t d2 = d1->getDerivative(param);
+            if (d2 == Zero)
+              continue;
+            residuals_params_second_derivatives[make_pair(eq, make_pair(param1, param))] = d2;
+          }
 
       for (first_derivatives_t::const_iterator it2 = first_derivatives.begin();
            it2 != first_derivatives.end(); it2++)
@@ -1520,32 +1753,35 @@ ModelTree::computeParamsDerivatives()
           jacobian_params_derivatives[make_pair(eq, make_pair(var, param))] = d2;
         }
 
-      for (second_derivatives_t::const_iterator it2 = jacobian_params_derivatives.begin();
-           it2 != jacobian_params_derivatives.end(); it2++)
+      if (paramsDerivsOrder == 2)
         {
-          int eq = it2->first.first;
-          int var = it2->first.second.first;
-          int param1 = it2->first.second.second;
-          expr_t d1 = it2->second;
+          for (second_derivatives_t::const_iterator it2 = jacobian_params_derivatives.begin();
+               it2 != jacobian_params_derivatives.end(); it2++)
+            {
+              int eq = it2->first.first;
+              int var = it2->first.second.first;
+              int param1 = it2->first.second.second;
+              expr_t d1 = it2->second;
 
-          expr_t d2 = d1->getDerivative(param);
-          if (d2 == Zero)
-            continue;
-          jacobian_params_second_derivatives[make_pair(eq, make_pair(var, make_pair(param1, param)))] = d2;
-        }
+              expr_t d2 = d1->getDerivative(param);
+              if (d2 == Zero)
+                continue;
+              jacobian_params_second_derivatives[make_pair(eq, make_pair(var, make_pair(param1, param)))] = d2;
+            }
 
-      for (second_derivatives_t::const_iterator it2 = second_derivatives.begin();
-           it2 != second_derivatives.end(); it2++)
-        {
-          int eq = it2->first.first;
-          int var1 = it2->first.second.first;
-          int var2 = it2->first.second.second;
-          expr_t d1 = it2->second;
+          for (second_derivatives_t::const_iterator it2 = second_derivatives.begin();
+               it2 != second_derivatives.end(); it2++)
+            {
+              int eq = it2->first.first;
+              int var1 = it2->first.second.first;
+              int var2 = it2->first.second.second;
+              expr_t d1 = it2->second;
 
-          expr_t d2 = d1->getDerivative(param);
-          if (d2 == Zero)
-            continue;
-          hessian_params_derivatives[make_pair(eq, make_pair(var1, make_pair(var2, param)))] = d2;
+              expr_t d2 = d1->getDerivative(param);
+              if (d2 == Zero)
+                continue;
+              hessian_params_derivatives[make_pair(eq, make_pair(var1, make_pair(var2, param)))] = d2;
+            }
         }
     }
 }
@@ -1553,33 +1789,59 @@ ModelTree::computeParamsDerivatives()
 void
 ModelTree::computeParamsDerivativesTemporaryTerms()
 {
-  map<expr_t, int> reference_count;
+  map<expr_t, pair<int, NodeTreeReference > > reference_count;
   params_derivs_temporary_terms.clear();
+  map<NodeTreeReference, temporary_terms_t> temp_terms_map;
+  temp_terms_map[eResidualsParamsDeriv] = params_derivs_temporary_terms_res;
+  temp_terms_map[eJacobianParamsDeriv] = params_derivs_temporary_terms_g1;
+  temp_terms_map[eResidualsParamsSecondDeriv] = params_derivs_temporary_terms_res2;
+  temp_terms_map[eJacobianParamsSecondDeriv] = params_derivs_temporary_terms_g12;
+  temp_terms_map[eHessianParamsDeriv] = params_derivs_temporary_terms_g2;
 
   for (first_derivatives_t::iterator it = residuals_params_derivatives.begin();
        it != residuals_params_derivatives.end(); it++)
-    it->second->computeTemporaryTerms(reference_count, params_derivs_temporary_terms, true);
+    it->second->computeTemporaryTerms(reference_count,
+                                      temp_terms_map,
+                                      true, eResidualsParamsDeriv);
 
   for (second_derivatives_t::iterator it = jacobian_params_derivatives.begin();
        it != jacobian_params_derivatives.end(); it++)
-    it->second->computeTemporaryTerms(reference_count, params_derivs_temporary_terms, true);
+    it->second->computeTemporaryTerms(reference_count,
+                                      temp_terms_map,
+                                      true, eJacobianParamsDeriv);
 
   for (second_derivatives_t::const_iterator it = residuals_params_second_derivatives.begin();
        it != residuals_params_second_derivatives.end(); ++it)
-    it->second->computeTemporaryTerms(reference_count, params_derivs_temporary_terms, true);
+    it->second->computeTemporaryTerms(reference_count,
+                                      temp_terms_map,
+                                      true, eResidualsParamsSecondDeriv);
 
   for (third_derivatives_t::const_iterator it = jacobian_params_second_derivatives.begin();
        it != jacobian_params_second_derivatives.end(); ++it)
-    it->second->computeTemporaryTerms(reference_count, params_derivs_temporary_terms, true);
+    it->second->computeTemporaryTerms(reference_count,
+                                      temp_terms_map,
+                                      true, eJacobianParamsSecondDeriv);
 
   for (third_derivatives_t::const_iterator it = hessian_params_derivatives.begin();
        it != hessian_params_derivatives.end(); ++it)
-    it->second->computeTemporaryTerms(reference_count, params_derivs_temporary_terms, true);
+    it->second->computeTemporaryTerms(reference_count,
+                                      temp_terms_map,
+                                      true, eHessianParamsDeriv);
+
+  for (map<NodeTreeReference, temporary_terms_t>::const_iterator it = temp_terms_map.begin();
+       it != temp_terms_map.end(); it++)
+    params_derivs_temporary_terms.insert(it->second.begin(), it->second.end());
+
+  params_derivs_temporary_terms_res  = temp_terms_map[eResidualsParamsDeriv];
+  params_derivs_temporary_terms_g1   = temp_terms_map[eJacobianParamsDeriv];
+  params_derivs_temporary_terms_res2 = temp_terms_map[eResidualsParamsSecondDeriv];
+  params_derivs_temporary_terms_g12  = temp_terms_map[eJacobianParamsSecondDeriv];
+  params_derivs_temporary_terms_g2   = temp_terms_map[eHessianParamsDeriv];
 }
 
-bool ModelTree::isNonstationary(int symb_id) const
+bool
+ModelTree::isNonstationary(int symb_id) const
 {
   return (nonstationary_symbols_map.find(symb_id)
           != nonstationary_symbols_map.end());
 }
-
