@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2012-2013 Dynare Team
+ * Copyright (C) 2012-2017 Dynare Team
  *
  * This file is part of Dynare.
  *
@@ -20,8 +20,9 @@
 #include "WarningConsolidation.hh"
 #include <ostream>
 
-WarningConsolidation&
-operator<< (WarningConsolidation& wcc, const string &warning)
+WarningConsolidation
+&
+operator<<(WarningConsolidation &wcc, const string &warning)
 {
   if (wcc.no_warn)
     return wcc;
@@ -31,8 +32,8 @@ operator<< (WarningConsolidation& wcc, const string &warning)
   return wcc;
 };
 
-WarningConsolidation&
-operator<< (WarningConsolidation& wcc, const Dynare::location& loc)
+WarningConsolidation &
+operator<<(WarningConsolidation &wcc, const Dynare::location &loc)
 {
   if (wcc.no_warn)
     return wcc;
@@ -54,8 +55,8 @@ operator<< (WarningConsolidation& wcc, const Dynare::location& loc)
   return wcc;
 };
 
-WarningConsolidation&
-operator<< (WarningConsolidation& wcc, ostream& (*pf) (ostream&))
+WarningConsolidation &
+operator<<(WarningConsolidation &wcc, ostream & (*pf)(ostream &))
 {
   if (wcc.no_warn)
     return wcc;
