@@ -29,18 +29,19 @@
 
 // This special exception was added by the Free Software Foundation in
 // version 2.2 of Bison.
+// //                    "%code top" blocks.
+#line 24 "MacroBison.yy" // lalr1.cc:392
+
+class MacroDriver;
+
+#line 38 "MacroBison.cc" // lalr1.cc:392
 
 // Take the name prefix into account.
 #define yylex   Macrolex
 
 // First part of user declarations.
-#line 30 "MacroBison.yy" // lalr1.cc:399
 
-#include "MacroValue.hh"
-
-class MacroDriver;
-
-#line 44 "MacroBison.cc" // lalr1.cc:399
+#line 45 "MacroBison.cc" // lalr1.cc:399
 
 # ifndef YY_NULLPTR
 #  if defined __cplusplus && 201103L <= __cplusplus
@@ -53,7 +54,10 @@ class MacroDriver;
 #include "MacroBison.hh"
 
 // User implementation prologue.
-#line 59 "MacroBison.yy" // lalr1.cc:407
+
+#line 59 "MacroBison.cc" // lalr1.cc:407
+// Unqualified %code blocks.
+#line 55 "MacroBison.yy" // lalr1.cc:408
 
 #include <cstdlib>  // Pour atoi()
 #include "MacroDriver.hh"
@@ -74,7 +78,7 @@ class MacroDriver;
     }
 
 
-#line 78 "MacroBison.cc" // lalr1.cc:407
+#line 82 "MacroBison.cc" // lalr1.cc:408
 
 
 #ifndef YY_
@@ -160,7 +164,7 @@ class MacroDriver;
 
 
 namespace Macro {
-#line 164 "MacroBison.cc" // lalr1.cc:474
+#line 168 "MacroBison.cc" // lalr1.cc:474
 
   /* Return YYSTR after stripping away unnecessary quotes and
      backslashes, so that it's suitable for yyerror.  The heuristic is
@@ -499,13 +503,13 @@ namespace Macro {
 
 
     // User initialization code.
-    #line 44 "MacroBison.yy" // lalr1.cc:725
+    #line 36 "MacroBison.yy" // lalr1.cc:725
 {
   // Initialize the location filenames
   yyla.location.begin.filename = yyla.location.end.filename = &driver.file;
 }
 
-#line 509 "MacroBison.cc" // lalr1.cc:725
+#line 513 "MacroBison.cc" // lalr1.cc:725
 
     /* Initialize the stack.  The initial state will be set in
        yynewstate, since the latter expects the semantical and the
@@ -617,67 +621,67 @@ namespace Macro {
           switch (yyn)
             {
   case 6:
-#line 111 "MacroBison.yy" // lalr1.cc:847
+#line 107 "MacroBison.yy" // lalr1.cc:847
     { out << (yystack_[0].value.mv)->toString(); }
-#line 623 "MacroBison.cc" // lalr1.cc:847
+#line 627 "MacroBison.cc" // lalr1.cc:847
     break;
 
   case 7:
-#line 113 "MacroBison.yy" // lalr1.cc:847
+#line 109 "MacroBison.yy" // lalr1.cc:847
     { driver.set_variable(*(yystack_[2].value.string_val), (yystack_[0].value.mv)); delete (yystack_[2].value.string_val); }
-#line 629 "MacroBison.cc" // lalr1.cc:847
+#line 633 "MacroBison.cc" // lalr1.cc:847
     break;
 
   case 8:
-#line 115 "MacroBison.yy" // lalr1.cc:847
+#line 111 "MacroBison.yy" // lalr1.cc:847
     { TYPERR_CATCH(driver.init_loop(*(yystack_[2].value.string_val), (yystack_[0].value.mv)), yylhs.location); delete (yystack_[2].value.string_val); }
-#line 635 "MacroBison.cc" // lalr1.cc:847
+#line 639 "MacroBison.cc" // lalr1.cc:847
     break;
 
   case 9:
-#line 117 "MacroBison.yy" // lalr1.cc:847
+#line 113 "MacroBison.yy" // lalr1.cc:847
     { TYPERR_CATCH(driver.begin_if((yystack_[0].value.mv)), yylhs.location); }
-#line 641 "MacroBison.cc" // lalr1.cc:847
+#line 645 "MacroBison.cc" // lalr1.cc:847
     break;
 
   case 10:
-#line 119 "MacroBison.yy" // lalr1.cc:847
+#line 115 "MacroBison.yy" // lalr1.cc:847
     { TYPERR_CATCH(driver.begin_ifdef(*(yystack_[0].value.string_val)), yylhs.location); delete (yystack_[0].value.string_val); }
-#line 647 "MacroBison.cc" // lalr1.cc:847
+#line 651 "MacroBison.cc" // lalr1.cc:847
     break;
 
   case 11:
-#line 121 "MacroBison.yy" // lalr1.cc:847
+#line 117 "MacroBison.yy" // lalr1.cc:847
     { TYPERR_CATCH(driver.begin_ifndef(*(yystack_[0].value.string_val)), yylhs.location); delete (yystack_[0].value.string_val); }
-#line 653 "MacroBison.cc" // lalr1.cc:847
+#line 657 "MacroBison.cc" // lalr1.cc:847
     break;
 
   case 12:
-#line 123 "MacroBison.yy" // lalr1.cc:847
+#line 119 "MacroBison.yy" // lalr1.cc:847
     { TYPERR_CATCH(driver.echo(yylhs.location, (yystack_[0].value.mv)), yylhs.location); }
-#line 659 "MacroBison.cc" // lalr1.cc:847
+#line 663 "MacroBison.cc" // lalr1.cc:847
     break;
 
   case 13:
-#line 125 "MacroBison.yy" // lalr1.cc:847
+#line 121 "MacroBison.yy" // lalr1.cc:847
     { TYPERR_CATCH(driver.error(yylhs.location, (yystack_[0].value.mv)), yylhs.location); }
-#line 665 "MacroBison.cc" // lalr1.cc:847
+#line 669 "MacroBison.cc" // lalr1.cc:847
     break;
 
   case 15:
-#line 131 "MacroBison.yy" // lalr1.cc:847
+#line 127 "MacroBison.yy" // lalr1.cc:847
     { (yylhs.value.mv) = new IntMV(driver, (yystack_[0].value.int_val)); }
-#line 671 "MacroBison.cc" // lalr1.cc:847
+#line 675 "MacroBison.cc" // lalr1.cc:847
     break;
 
   case 16:
-#line 133 "MacroBison.yy" // lalr1.cc:847
+#line 129 "MacroBison.yy" // lalr1.cc:847
     { (yylhs.value.mv) = new StringMV(driver, *(yystack_[0].value.string_val)); delete (yystack_[0].value.string_val); }
-#line 677 "MacroBison.cc" // lalr1.cc:847
+#line 681 "MacroBison.cc" // lalr1.cc:847
     break;
 
   case 17:
-#line 135 "MacroBison.yy" // lalr1.cc:847
+#line 131 "MacroBison.yy" // lalr1.cc:847
     {
          try
            {
@@ -689,113 +693,118 @@ namespace Macro {
            }
          delete (yystack_[0].value.string_val);
        }
-#line 693 "MacroBison.cc" // lalr1.cc:847
+#line 697 "MacroBison.cc" // lalr1.cc:847
     break;
 
   case 18:
-#line 147 "MacroBison.yy" // lalr1.cc:847
+#line 143 "MacroBison.yy" // lalr1.cc:847
     { TYPERR_CATCH((yylhs.value.mv) = (yystack_[1].value.mv)->length(), yylhs.location); }
-#line 699 "MacroBison.cc" // lalr1.cc:847
+#line 703 "MacroBison.cc" // lalr1.cc:847
     break;
 
   case 19:
-#line 149 "MacroBison.yy" // lalr1.cc:847
+#line 145 "MacroBison.yy" // lalr1.cc:847
     { (yylhs.value.mv) = (yystack_[1].value.mv); }
-#line 705 "MacroBison.cc" // lalr1.cc:847
+#line 709 "MacroBison.cc" // lalr1.cc:847
     break;
 
   case 20:
-#line 151 "MacroBison.yy" // lalr1.cc:847
+#line 147 "MacroBison.yy" // lalr1.cc:847
     { TYPERR_CATCH((yylhs.value.mv) = *(yystack_[2].value.mv) + *(yystack_[0].value.mv), yylhs.location); }
-#line 711 "MacroBison.cc" // lalr1.cc:847
+#line 715 "MacroBison.cc" // lalr1.cc:847
     break;
 
   case 21:
-#line 153 "MacroBison.yy" // lalr1.cc:847
+#line 149 "MacroBison.yy" // lalr1.cc:847
     { TYPERR_CATCH((yylhs.value.mv) = *(yystack_[2].value.mv) - *(yystack_[0].value.mv), yylhs.location); }
-#line 717 "MacroBison.cc" // lalr1.cc:847
+#line 721 "MacroBison.cc" // lalr1.cc:847
     break;
 
   case 22:
-#line 155 "MacroBison.yy" // lalr1.cc:847
+#line 151 "MacroBison.yy" // lalr1.cc:847
     { TYPERR_CATCH((yylhs.value.mv) = *(yystack_[2].value.mv) * *(yystack_[0].value.mv), yylhs.location); }
-#line 723 "MacroBison.cc" // lalr1.cc:847
+#line 727 "MacroBison.cc" // lalr1.cc:847
     break;
 
   case 23:
-#line 157 "MacroBison.yy" // lalr1.cc:847
-    { TYPERR_CATCH((yylhs.value.mv) = *(yystack_[2].value.mv) / *(yystack_[0].value.mv), yylhs.location); }
-#line 729 "MacroBison.cc" // lalr1.cc:847
+#line 153 "MacroBison.yy" // lalr1.cc:847
+    {
+         if (dynamic_cast<const IntMV *>((yystack_[0].value.mv)) != NULL
+             && ((IntMV *)(yystack_[0].value.mv))->get_int_value() == 0)
+           driver.error(yylhs.location, "Division by zero");
+         TYPERR_CATCH((yylhs.value.mv) = *(yystack_[2].value.mv) / *(yystack_[0].value.mv), yylhs.location);
+       }
+#line 738 "MacroBison.cc" // lalr1.cc:847
     break;
 
   case 24:
-#line 159 "MacroBison.yy" // lalr1.cc:847
+#line 160 "MacroBison.yy" // lalr1.cc:847
     { TYPERR_CATCH((yylhs.value.mv) = *(yystack_[2].value.mv) < *(yystack_[0].value.mv), yylhs.location); }
-#line 735 "MacroBison.cc" // lalr1.cc:847
+#line 744 "MacroBison.cc" // lalr1.cc:847
     break;
 
   case 25:
-#line 161 "MacroBison.yy" // lalr1.cc:847
+#line 162 "MacroBison.yy" // lalr1.cc:847
     { TYPERR_CATCH((yylhs.value.mv) = *(yystack_[2].value.mv) > *(yystack_[0].value.mv), yylhs.location); }
-#line 741 "MacroBison.cc" // lalr1.cc:847
+#line 750 "MacroBison.cc" // lalr1.cc:847
     break;
 
   case 26:
-#line 163 "MacroBison.yy" // lalr1.cc:847
+#line 164 "MacroBison.yy" // lalr1.cc:847
     { TYPERR_CATCH((yylhs.value.mv) = *(yystack_[2].value.mv) <= *(yystack_[0].value.mv), yylhs.location); }
-#line 747 "MacroBison.cc" // lalr1.cc:847
+#line 756 "MacroBison.cc" // lalr1.cc:847
     break;
 
   case 27:
-#line 165 "MacroBison.yy" // lalr1.cc:847
+#line 166 "MacroBison.yy" // lalr1.cc:847
     { TYPERR_CATCH((yylhs.value.mv) = *(yystack_[2].value.mv) >= *(yystack_[0].value.mv), yylhs.location); }
-#line 753 "MacroBison.cc" // lalr1.cc:847
+#line 762 "MacroBison.cc" // lalr1.cc:847
     break;
 
   case 28:
-#line 167 "MacroBison.yy" // lalr1.cc:847
+#line 168 "MacroBison.yy" // lalr1.cc:847
     { TYPERR_CATCH((yylhs.value.mv) = *(yystack_[2].value.mv) == *(yystack_[0].value.mv), yylhs.location); }
-#line 759 "MacroBison.cc" // lalr1.cc:847
+#line 768 "MacroBison.cc" // lalr1.cc:847
     break;
 
   case 29:
-#line 169 "MacroBison.yy" // lalr1.cc:847
+#line 170 "MacroBison.yy" // lalr1.cc:847
     { TYPERR_CATCH((yylhs.value.mv) = *(yystack_[2].value.mv) != *(yystack_[0].value.mv), yylhs.location); }
-#line 765 "MacroBison.cc" // lalr1.cc:847
+#line 774 "MacroBison.cc" // lalr1.cc:847
     break;
 
   case 30:
-#line 171 "MacroBison.yy" // lalr1.cc:847
+#line 172 "MacroBison.yy" // lalr1.cc:847
     { TYPERR_CATCH((yylhs.value.mv) = *(yystack_[2].value.mv) || *(yystack_[0].value.mv), yylhs.location); }
-#line 771 "MacroBison.cc" // lalr1.cc:847
+#line 780 "MacroBison.cc" // lalr1.cc:847
     break;
 
   case 31:
-#line 173 "MacroBison.yy" // lalr1.cc:847
+#line 174 "MacroBison.yy" // lalr1.cc:847
     { TYPERR_CATCH((yylhs.value.mv) = *(yystack_[2].value.mv) && *(yystack_[0].value.mv), yylhs.location); }
-#line 777 "MacroBison.cc" // lalr1.cc:847
+#line 786 "MacroBison.cc" // lalr1.cc:847
     break;
 
   case 32:
-#line 175 "MacroBison.yy" // lalr1.cc:847
+#line 176 "MacroBison.yy" // lalr1.cc:847
     { TYPERR_CATCH((yylhs.value.mv) = -*(yystack_[0].value.mv), yylhs.location); }
-#line 783 "MacroBison.cc" // lalr1.cc:847
+#line 792 "MacroBison.cc" // lalr1.cc:847
     break;
 
   case 33:
-#line 177 "MacroBison.yy" // lalr1.cc:847
+#line 178 "MacroBison.yy" // lalr1.cc:847
     { TYPERR_CATCH((yylhs.value.mv) = +(*(yystack_[0].value.mv)), yylhs.location); }
-#line 789 "MacroBison.cc" // lalr1.cc:847
+#line 798 "MacroBison.cc" // lalr1.cc:847
     break;
 
   case 34:
-#line 179 "MacroBison.yy" // lalr1.cc:847
+#line 180 "MacroBison.yy" // lalr1.cc:847
     { TYPERR_CATCH((yylhs.value.mv) = !*(yystack_[0].value.mv), yylhs.location); }
-#line 795 "MacroBison.cc" // lalr1.cc:847
+#line 804 "MacroBison.cc" // lalr1.cc:847
     break;
 
   case 35:
-#line 181 "MacroBison.yy" // lalr1.cc:847
+#line 182 "MacroBison.yy" // lalr1.cc:847
     {
          TYPERR_CATCH((yylhs.value.mv) = (*(yystack_[3].value.mv))[*(yystack_[1].value.mv)], yylhs.location)
          catch(MacroValue::OutOfBoundsError)
@@ -803,41 +812,41 @@ namespace Macro {
              error(yylhs.location, "Index out of bounds");
            }
        }
-#line 807 "MacroBison.cc" // lalr1.cc:847
+#line 816 "MacroBison.cc" // lalr1.cc:847
     break;
 
   case 36:
-#line 189 "MacroBison.yy" // lalr1.cc:847
+#line 190 "MacroBison.yy" // lalr1.cc:847
     { (yylhs.value.mv) = (yystack_[1].value.mv); }
-#line 813 "MacroBison.cc" // lalr1.cc:847
+#line 822 "MacroBison.cc" // lalr1.cc:847
     break;
 
   case 37:
-#line 191 "MacroBison.yy" // lalr1.cc:847
+#line 192 "MacroBison.yy" // lalr1.cc:847
     { TYPERR_CATCH((yylhs.value.mv) = IntMV::new_range(driver, (yystack_[2].value.mv), (yystack_[0].value.mv)), yylhs.location); }
-#line 819 "MacroBison.cc" // lalr1.cc:847
+#line 828 "MacroBison.cc" // lalr1.cc:847
     break;
 
   case 38:
-#line 193 "MacroBison.yy" // lalr1.cc:847
+#line 194 "MacroBison.yy" // lalr1.cc:847
     { TYPERR_CATCH((yylhs.value.mv) = (yystack_[2].value.mv)->in((yystack_[0].value.mv)), yylhs.location); }
-#line 825 "MacroBison.cc" // lalr1.cc:847
+#line 834 "MacroBison.cc" // lalr1.cc:847
     break;
 
   case 39:
-#line 197 "MacroBison.yy" // lalr1.cc:847
+#line 198 "MacroBison.yy" // lalr1.cc:847
     { (yylhs.value.mv) = (yystack_[0].value.mv)->toArray(); }
-#line 831 "MacroBison.cc" // lalr1.cc:847
+#line 840 "MacroBison.cc" // lalr1.cc:847
     break;
 
   case 40:
-#line 199 "MacroBison.yy" // lalr1.cc:847
+#line 200 "MacroBison.yy" // lalr1.cc:847
     { TYPERR_CATCH((yylhs.value.mv) = (yystack_[0].value.mv)->append((yystack_[2].value.mv)), yylhs.location); }
-#line 837 "MacroBison.cc" // lalr1.cc:847
+#line 846 "MacroBison.cc" // lalr1.cc:847
     break;
 
 
-#line 841 "MacroBison.cc" // lalr1.cc:847
+#line 850 "MacroBison.cc" // lalr1.cc:847
             default:
               break;
             }
@@ -1243,11 +1252,11 @@ namespace Macro {
   const unsigned char
   parser::yyrline_[] =
   {
-       0,   102,   102,   103,   106,   107,   110,   112,   114,   116,
-     118,   120,   122,   124,   126,   130,   132,   134,   146,   148,
-     150,   152,   154,   156,   158,   160,   162,   164,   166,   168,
-     170,   172,   174,   176,   178,   180,   188,   190,   192,   196,
-     198
+       0,    98,    98,    99,   102,   103,   106,   108,   110,   112,
+     114,   116,   118,   120,   122,   126,   128,   130,   142,   144,
+     146,   148,   150,   152,   159,   161,   163,   165,   167,   169,
+     171,   173,   175,   177,   179,   181,   189,   191,   193,   197,
+     199
   };
 
   // Print the state stack on the debug stream.
@@ -1332,8 +1341,8 @@ namespace Macro {
 
 
 } // Macro
-#line 1336 "MacroBison.cc" // lalr1.cc:1155
-#line 202 "MacroBison.yy" // lalr1.cc:1156
+#line 1345 "MacroBison.cc" // lalr1.cc:1155
+#line 203 "MacroBison.yy" // lalr1.cc:1156
 
 
 void
